@@ -386,7 +386,7 @@ extern RpcList_t *RPC_RemoveListEntry(RpcList_t **listTop,void *remEntry) {
 	return (RpcList_t*)NULL;
 }
 
-extern void RPC_SearchAndFreeListData(RpcList_t **listTop,uint32_t id,uint32_t allocId,RPC_CompareFunc compareFunc,RPC_FreeFunc_t freeFunc) {
+extern void RPC_SearchAndFreeListData(RpcList_t **listTop,uint32_t id,uint32_t allocId,RPC_CompareFunc_t compareFunc,RPC_FreeFunc_t freeFunc) {
 	RpcList_t *list,*prev;
 
 	if(listTop == (RpcList_t**)NULL)
@@ -409,7 +409,7 @@ extern void RPC_SearchAndFreeListData(RpcList_t **listTop,uint32_t id,uint32_t a
 	return;
 }
 
-extern void *RPC_SearchListEntryById(RpcList_t *listTop,uint32_t id,RPC_CompareFunc compareFunc) {
+extern void *RPC_SearchListEntryById(RpcList_t *listTop,uint32_t id,RPC_CompareFunc_t compareFunc) {
 	RpcList_t *list;
 
 	for(list = listTop;list != (RpcList_t*)NULL;list = (RpcList_t*)list->next) {
@@ -420,7 +420,7 @@ extern void *RPC_SearchListEntryById(RpcList_t *listTop,uint32_t id,RPC_CompareF
 	return (void*)NULL;
 }
 
-extern void *RPC_SearchListEntryByIds(RpcList_t *listTop,uint32_t id1,uint32_t id2,RPC_compareFuncByIds compareFunc) {
+extern void *RPC_SearchListEntryByIds(RpcList_t *listTop,uint32_t id1,uint32_t id2,RPC_compareFuncByIds_t compareFunc) {
 	RpcList_t *list;
 
 	for(list = listTop;list != (RpcList_t*)NULL;list = (RpcList_t*)list->next) {
@@ -431,6 +431,17 @@ extern void *RPC_SearchListEntryByIds(RpcList_t *listTop,uint32_t id1,uint32_t i
 	return (void*)NULL;
 }
 
+extern void *RPC_SearchListEntryByString(RpcList_t *listTop,uint8_t *str,uint32_t strLen,RPC_compareFuncByString_t compareFunc) {
+	RpcList_t *list;
+
+	for(list = listTop;list != (RpcList_t*)NULL;list = (RpcList_t*)list->next) {
+		if(compareFunc(list,str,strLen)) {
+			return (void*)list->entry;
+		}
+	}
+	return (void*)NULL;
+}
+
 extern uint32_t RPC_CountNumOfListEntry(RpcList_t *listTop) {
 	RpcList_t *list;uint32_t num = 0;
 
@@ -467,6 +478,7 @@ extern RpcBool_t RPC_SetTimeout(uint32_t timeout, struct timeval *absTime) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_ERROR,"ERROR IN  RPC_GetTimeOfDay ERR-CODE:%s;",RPC_LogConvertErrCode(errCode));
 		return RPC_FALSE;
 	}
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG3,"CUR TIME:%d.%d;",curTime.tv_sec,curTime.tv_usec);
 	absTime->tv_sec = curTime.tv_sec;
 	absTime->tv_usec = curTime.tv_usec + timeout*1000;
 	absTime->tv_sec += ((absTime->tv_usec)/1000000);
