@@ -59,8 +59,9 @@ typedef struct {
 typedef RpcBool_t (*RPC_CompareHashVal_t)(void *entry, uint8_t *val, uint32_t valSize);
 typedef void* (*RPC_AllocFunc_t)(uint32_t allocId,uint32_t size);
 typedef void (*RPC_FreeFunc_t)(uint32_t allocId,void *area);
-typedef RpcBool_t (*RPC_CompareFunc)(RpcList_t *list,uint32_t id);
-typedef RpcBool_t (*RPC_compareFuncByIds)(RpcList_t *list,uint32_t id1,uint32_t id2);
+typedef RpcBool_t (*RPC_CompareFunc_t)(RpcList_t *list,uint32_t id);
+typedef RpcBool_t (*RPC_compareFuncByIds_t)(RpcList_t *list,uint32_t id1,uint32_t id2);
+typedef RpcBool_t (*RPC_compareFuncByString_t)(RpcList_t *list,uint8_t *str,uint32_t strLen);
 
 extern RpcResult_t RPC_CreateTaskControl(RpcBool_t IpcFlag,RpcTaskControl_t *tskCntl);
 extern void RPC_DestroyTaskControl(RpcTaskControl_t *tskCntl);
@@ -78,13 +79,14 @@ extern void *RPC_SearchEntryByHash(RpcHashEntry_t *hashTblTop, uint8_t *val, uin
 extern void *RPC_AllocListData(RpcList_t **listTop,uint32_t entitySize,uint32_t allocId,RPC_AllocFunc_t allocFunc,RPC_FreeFunc_t freeFunc);
 extern void RPC_FreeListData(RpcList_t **listTop,void *delEntry,uint32_t allocId,RPC_FreeFunc_t freeFunc);
 extern RpcList_t *RPC_RemoveListEntry(RpcList_t **listTop,void *remEntry);
-extern void RPC_SearchAndFreeListData(RpcList_t **ListTop,uint32_t id,uint32_t allocId,RPC_CompareFunc compareFunc,RPC_FreeFunc_t freeFunc);
+extern void RPC_SearchAndFreeListData(RpcList_t **ListTop,uint32_t id,uint32_t allocId,RPC_CompareFunc_t compareFunc,RPC_FreeFunc_t freeFunc);
 extern void *RPC_ShmAllocMemWrapper(uint32_t allocId,uint32_t size);
 extern void RPC_ShmFreeMemWrapper(uint32_t allocId,void *area);
 extern void *RPC_LclAllocMemWrapper(uint32_t allocId,uint32_t size);
 extern void RPC_LclFreeMemWrapper(uint32_t allocId,void *area);
-extern void *RPC_SearchListEntryById(RpcList_t *listTop, uint32_t id, RPC_CompareFunc compareFunc);
-extern void *RPC_SearchListEntryByIds(RpcList_t *listTop,uint32_t id1,uint32_t id2,RPC_compareFuncByIds compareFunc);
+extern void *RPC_SearchListEntryById(RpcList_t *listTop, uint32_t id, RPC_CompareFunc_t compareFunc);
+extern void *RPC_SearchListEntryByIds(RpcList_t *listTop,uint32_t id1,uint32_t id2,RPC_compareFuncByIds_t compareFunc);
+extern void *RPC_SearchListEntryByString(RpcList_t *listTop,uint8_t *str,uint32_t strLen,RPC_compareFuncByString_t compareFunc);
 extern uint32_t RPC_CountNumOfListEntry(RpcList_t *listTop);
 
 extern RpcBool_t RPC_SetTimeout(uint32_t timeout, struct timeval *absTime);
