@@ -293,13 +293,14 @@ static char *RPC_logConvertModule(RpcLogModule_t module) {
 	case RPC_LOG_MODULE_MSG_QUE:		return "MSGQUE";
 	case RPC_LOG_MODULE_SHM:		return "SHM   ";
 	case RPC_LOG_MODULE_SHM_DB:		return "SHM DB";
-	case RPC_LOG_MODULE_LIB:		return "LIB   ";
+	case RPC_LOG_MODULE_LIB:		return "IPCLIB";
 	case RPC_LOG_MODULE_MARSHAL:		return "MARSHL";
 	case RPC_LOG_MODULE_STUB:		return "STUB  ";
 	case RPC_LOG_MODULE_SKELTON:		return "SKELTN";
 	case RPC_LOG_MODULE_RENDEZV:		return "RENDZV";
 //	case RPC_LOG_MODULE_PRCSS_CNTL:		return "PRCSS ";
 	case RPC_LOG_MODULE_MLTCST:		return "MLTCST";
+	case RPC_LOG_MODULE_INIT:		return "IPCINT";
 #ifdef	USE_IDC
 	default:				return IDC_logConvertModule((IdcLogModule_t)module);
 #else	/* USE_IDC */
