@@ -45,12 +45,37 @@
 #include	"ipcStub.h"
 #include	"ipcMarshal.h"
 
+#define	IPC_NO_RESTRICTION_LENGTH			0xFFFFFFFF
+#define	IPC_ENABLE_UNKNOWN_TYPE_LENGTH			0x00000000
+#define	IPC_ENABLE_INT_TYPE_LENGTH			0x0000000F
+#define	IPC_ENABLE_UINT_TYPE_LENGTH			0x0000000F
+#ifdef	IEEE754_LONG_DOUBLE_BIAS
+#define	IPC_ENABLE_FLOAT_TYPE_LENGTH			0x0000001C
+#else	/* IEEE854_LONG_DOUBLE_BIAS */
+#define	IPC_ENABLE_FLOAT_TYPE_LENGTH			0x0000000C
+#endif	/* IEEE854_LONG_DOUBLE_BIAS */
+#define	IPC_ENABLE_ENUM_TYPE_LENGTH			0x00000004
+#define	IPC_ENABLE_STRING_TYPE_LENGTH			IPC_NO_RESTRICTION_LENGTH
+#define	IPC_ENABLE_OCTET_ARRAY_TYPE_LENGTH		IPC_NO_RESTRICTION_LENGTH
+#define	IPC_ENABLE_BOOLEAN_TYPE_LENGTH			0x00000001
+#ifndef	USE_IDC
+#define	IPC_ENABLE_REFERENCE_TYPE_LENGTH		0x00000008
+#else	/* USE_IDC */
+#define	IPC_ENABLE_REFERENCE_TYPE_LENGTH		0x00000010
+#endif	/* USE_IDC */
+
 static int32_t IpcMarshalDataSharedMemId = -1;
 
 static RpcResult_t IPC_parseOneData(RpcParamData_t *inData,uint32_t *useSize);
+static RpcResult_t IPC_checkParamLength(uint32_t paramLeng,uint32_t enableLeng);
 static RpcResult_t IPC_putOneData(RpcParamData_t *inData,void *outData,uint32_t outSize,uint32_t *useSize);
 static RpcResult_t IPC_parseMarshaledData(void *inData,uint32_t inSize,uint32_t *needSize,RpcParamData_t *pData);
 
+#ifdef	RPC_CHECK_BYTEORDER
+static void IPC_convertNetworkByteOrder(void *inData,void *outData,uint32_t size);
+static void IPC_convertHostByteOrder(void *inData,void *outData,uint32_t size);
+#endif	/* RPC_CHECK_BYTEORDER */
+
 void IPC_DumpParamData(RpcParamData_t *pData);
 uint8_t *IPC_ConvertTypeToString(RpcParamType_t type);
 
@@ -92,6 +117,8 @@ extern RpcResult_t IPC_Marshal(RpcParamData_t *inData, void **outData, uint32_t
 	}
 	*outSize = 0;
 	for(p = inData;p->paramSpec.paramType != RPC_TYPE_UNKNOWN;p++) {
+//		(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL,RPC_LOG_LEVEL_DEBUG3,"  TYPE:%s; LENG:%d; DATA:0x%x;",
+//			IPC_ConvertTypeToString(p->paramSpec.paramType),p->paramSpec.paramLeng,p->paramData);
 		if((ret = IPC_parseOneData(p,&oneSize)) != RPC_SUCCESS) {
 			*outSize = 0;*outData = NULL;
 			return ret;
@@ -106,7 +133,11 @@ extern RpcResult_t IPC_Marshal(RpcParamData_t *inData, void **outData, uint32_t
 	}
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL,RPC_LOG_LEVEL_DEBUG2," NOW 3rd Stage, outData:0x%x;",*outData);
 	header = (RpcParamHeader_t*)outP;
+#ifndef	RPC_CHECK_BYTEORDER
 	header->paramLength = *outSize;
+#else	/* RPC_CHECK_BYTEORDER */
+	IPC_convertNetworkByteOrder((void*)outSize,(void*)&(header->paramLength),sizeof(header->paramLength));
+#endif	/* RPC_CHECK_BYTEORDER */
 	header->reserved = 0;
 	tmpSize = *outSize - sizeof(RpcParamHeader_t);
 	outP = (void*)&(((uint8_t*)outP)[sizeof(RpcParamHeader_t)]);
@@ -131,6 +162,7 @@ extern RpcResult_t IPC_Marshal(RpcParamData_t *inData, void **outData, uint32_t
 extern RpcResult_t IPC_Unmarshal(void *inData, uint32_t inSize, void *outData, uint32_t outSize) {
 	RpcParamData_t *pData;void *inP,*outP;int32_t size,needSize,oSize;
 	RpcResult_t ret;RpcParamHeader_t *header;
+	uint32_t temp;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL,RPC_LOG_LEVEL_DEBUG1,"IN IPC_Unmarshal inData:0x%x; inSize:%d; outData:0x%x; outSize:%d;",
 //		inData, inSize, outData, outSize);
@@ -142,6 +174,10 @@ extern RpcResult_t IPC_Unmarshal(void *inData, uint32_t inSize, void *outData, u
 	}
 //	inP = inData; size = inSize;
 	header = (RpcParamHeader_t*)inData;
+#ifdef	RPC_CHECK_BYTEORDER
+	IPC_convertHostByteOrder((void*)&(header->paramLength),(void*)&temp,sizeof(header->paramLength));
+	header->paramLength = temp;
+#endif	/* RPC_CHECK_BYTEORDER */
 	if(header->paramLength != inSize) {
 		return RPC_PARAM_ERROR;
 	}
@@ -168,7 +204,7 @@ extern RpcResult_t IPC_Unmarshal(void *inData, uint32_t inSize, void *outData, u
 		if(pData->paramSpec.paramType == RPC_TYPE_UNKNOWN)
 			break;
 		pData++;
-		outP = (void*)pData;
+//		outP = (void*)pData;
 	}
 	pData++;
 	outP = (void*)pData;
@@ -178,9 +214,41 @@ extern RpcResult_t IPC_Unmarshal(void *inData, uint32_t inSize, void *outData, u
 		if(oSize < IPC_ALIGNMENT(pData->paramSpec.paramLeng)) {
 			return RPC_NO_MORE_RESOURCE;
 		}
+#ifndef	RPC_CHECK_BYTEORDER
 		(void)memcpy(outP,pData->paramData,pData->paramSpec.paramLeng);
-		outP = (void*)&(((uint8_t*)outP)[IPC_ALIGNMENT(pData->paramSpec.paramLeng)]);
-		oSize -= IPC_ALIGNMENT(pData->paramSpec.paramLeng);
+#else	/* RPC_CHECK_BYTEORDER */
+		switch(pData->paramSpec.paramType) {
+		case RPC_INT_TYPE:
+		case RPC_UINT_TYPE:
+		case RPC_ENUM_TYPE:
+		case RPC_BOOLEAN_TYPE:
+		case RPC_FLOAT_TYPE:
+		case RPC_REFERENCE_TYPE:
+			IPC_convertHostByteOrder((void*)pData->paramData,(void*)outP,pData->paramSpec.paramLeng);
+			temp = pData->paramSpec.paramLeng;
+			break;
+		case RPC_OCTET_ARRAY_TYPE:
+			(void)memcpy(outP,pData->paramData,pData->paramSpec.paramLeng);
+			temp = pData->paramSpec.paramLeng;
+			break;
+		case RPC_STRING_TYPE:
+			(void)memcpy(outP,pData->paramData,pData->paramSpec.paramLeng);
+			((uint8_t*)outP)[pData->paramSpec.paramLeng] = 0;
+			temp = pData->paramSpec.paramLeng+1;
+			break;
+		case RPC_TYPE_UNKNOWN:
+			temp = pData->paramSpec.paramLeng;
+			break;
+		default:
+			break;
+		}
+#endif	/* RPC_CHECK_BYTEORDER */
+		if(temp > 0)
+			pData->paramData = outP;
+		else
+			pData->paramData = (uint8_t*)NULL;
+		outP = (void*)&(((uint8_t*)outP)[IPC_ALIGNMENT(temp)]);
+		oSize -= IPC_ALIGNMENT(temp);
 	}
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG2, "  FREE MEM inData:0x%x;",inData);
 	IPC_FreeShmMem(IpcMarshalDataSharedMemId, inData);
@@ -202,7 +270,11 @@ extern uint32_t IPC_GetMarshaledDataSize(void *data) {
 	if(data == (void*)NULL)
 		return (uint32_t)0;
 	header = (RpcParamHeader_t*)data;
+#ifndef	RPC_CHECK_BYTEORDER
 	size = header->paramLength;
+#else	/* RPC_CHECK_BYTEORDER */
+	IPC_convertHostByteOrder((void*)&(header->paramLength),(void*)&size,sizeof(header->paramLength));
+#endif	/* RPC_CHECK_BYTEORDER */
 	return size;
 }
 
@@ -232,24 +304,57 @@ extern void IPC_SetMsgParam(RpcMsgParam_t *msgParam,uint32_t funcId,uint32_t pId
 /* ----- Internal Functions ----- */
 
 static RpcResult_t IPC_parseOneData(RpcParamData_t *inData,uint32_t *useSize) {
+	uint32_t enableLength;
+
 	*useSize = sizeof(RpcParamSpec_t);
 	switch(inData->paramSpec.paramType) {
 	case RPC_INT_TYPE:
+		enableLength = IPC_ENABLE_INT_TYPE_LENGTH; break;
 	case RPC_UINT_TYPE:
+		enableLength = IPC_ENABLE_UINT_TYPE_LENGTH; break;
 	case RPC_FLOAT_TYPE:
+		enableLength = IPC_ENABLE_FLOAT_TYPE_LENGTH; break;
 	case RPC_STRING_TYPE:
-	case RPC_ENUM_TYPE:
-	case RPC_OTHER_TYPE:
-	case RPC_TYPE_UNKNOWN:
+		enableLength = IPC_ENABLE_STRING_TYPE_LENGTH;
+		if(strlen(inData->paramData) != inData->paramSpec.paramLeng) {
+			*useSize = 0;
+			return (RPC_PARAM_ERROR);
+		}
 		break;
+	case RPC_ENUM_TYPE:
+		enableLength = IPC_ENABLE_ENUM_TYPE_LENGTH; break;
+	case RPC_OCTET_ARRAY_TYPE:
+		enableLength = IPC_ENABLE_OCTET_ARRAY_TYPE_LENGTH; break;
+	case RPC_TYPE_UNKNOWN:
+		enableLength = IPC_ENABLE_UNKNOWN_TYPE_LENGTH; break;
+	case RPC_BOOLEAN_TYPE:
+		enableLength = IPC_ENABLE_BOOLEAN_TYPE_LENGTH; break;
+	case RPC_REFERENCE_TYPE:
+		enableLength = IPC_ENABLE_REFERENCE_TYPE_LENGTH; break;
 	default:
 		*useSize = 0;
 		return (RPC_PARAM_ERROR);
 	}
+	if(IPC_checkParamLength(inData->paramSpec.paramLeng,enableLength) != RPC_SUCCESS) {
+		*useSize = 0;
+		return RPC_PARAM_ERROR;
+	}
 	*useSize += IPC_ALIGNMENT(inData->paramSpec.paramLeng);
 	return RPC_SUCCESS;
 }
 
+static RpcResult_t IPC_checkParamLength(uint32_t paramLeng,uint32_t enableLeng) {
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG3, "IN IPC_checkParamLength paramLeng:0x%x; enableLeng:0x%x;",paramLeng,enableLeng);
+	if(enableLeng == IPC_NO_RESTRICTION_LENGTH)
+		return RPC_SUCCESS;
+	else if((enableLeng == 0)&&(paramLeng == 0))
+		return RPC_SUCCESS;
+	else if(paramLeng & enableLeng)
+		return RPC_SUCCESS;
+	else
+		return RPC_PARAM_ERROR;
+}
+
 static RpcResult_t IPC_putOneData(RpcParamData_t *inData,void *outData,uint32_t outSize,uint32_t *useSize) {
 	RpcResult_t ret = RPC_SUCCESS;
 	RpcParamSpec_t *paramSpec;void *dataP;int rest;
@@ -270,11 +375,18 @@ static RpcResult_t IPC_putOneData(RpcParamData_t *inData,void *outData,uint32_t
 	case RPC_FLOAT_TYPE:
 	case RPC_STRING_TYPE:
 	case RPC_ENUM_TYPE:
-	case RPC_OTHER_TYPE:
+	case RPC_OCTET_ARRAY_TYPE:
 	case RPC_TYPE_UNKNOWN:
+	case RPC_BOOLEAN_TYPE:
+	case RPC_REFERENCE_TYPE:
+#ifndef	RPC_CHECK_BYTEORDER
 		paramSpec->paramType = inData->paramSpec.paramType;
 		paramSpec->paramLeng = inData->paramSpec.paramLeng;
-		if((paramSpec->paramLeng > 0)&&(outSize < (*useSize + IPC_ALIGNMENT(paramSpec->paramLeng)))) {
+#else	/* RPC_CHECK_BYTEORDER */
+		IPC_convertNetworkByteOrder((void*)&(inData->paramSpec.paramType),(void*)&(paramSpec->paramType),sizeof(inData->paramSpec.paramType));
+		IPC_convertNetworkByteOrder((void*)&(inData->paramSpec.paramLeng),(void*)&(paramSpec->paramLeng),sizeof(inData->paramSpec.paramLeng));
+#endif	/* RPC_CHECK_BYTEORDER */
+		if((inData->paramSpec.paramLeng > 0)&&(outSize < (*useSize + IPC_ALIGNMENT(inData->paramSpec.paramLeng)))) {
 			ret = RPC_NO_MORE_RESOURCE;
 			goto errOut;
 		}
@@ -283,10 +395,29 @@ static RpcResult_t IPC_putOneData(RpcParamData_t *inData,void *outData,uint32_t
 		ret = RPC_PARAM_ERROR;
 		goto errOut;
 	}
-	if(paramSpec->paramLeng > 0) {
-		*useSize += paramSpec->paramLeng;
-		(void)memcpy(dataP,(void*)inData->paramData,paramSpec->paramLeng);
-		rest = IPC_ALIGNMENT(paramSpec->paramLeng) - paramSpec->paramLeng;
+	if(inData->paramSpec.paramLeng > 0) {
+		*useSize += inData->paramSpec.paramLeng;
+#ifndef	RPC_CHECK_BYTEORDER
+		(void)memcpy(dataP,(void*)inData->paramData,inData->paramSpec.paramLeng);
+#else	/* RPC_CHECK_BYTEORDER */
+		switch(inData->paramSpec.paramType) {
+		case RPC_INT_TYPE:
+		case RPC_UINT_TYPE:
+		case RPC_FLOAT_TYPE:
+		case RPC_ENUM_TYPE:
+		case RPC_BOOLEAN_TYPE:
+		case RPC_REFERENCE_TYPE:
+			IPC_convertNetworkByteOrder((void*)inData->paramData,(void*)dataP,inData->paramSpec.paramLeng);
+			break;
+		case RPC_STRING_TYPE:
+		case RPC_OCTET_ARRAY_TYPE:
+			(void)memcpy(dataP,(void*)inData->paramData,inData->paramSpec.paramLeng);
+			break;
+		default:
+			break;
+		}
+#endif	/* RPC_CHECK_BYTEORDER */
+		rest = IPC_ALIGNMENT(inData->paramSpec.paramLeng) - inData->paramSpec.paramLeng;
 		if(rest > 0) {
 			dataP = (void*)&(((uint8_t*)outData)[*useSize]);
 			(void)memset(dataP,0,rest);
@@ -301,40 +432,153 @@ errOut:
 
 static RpcResult_t IPC_parseMarshaledData(void *inData,uint32_t inSize,uint32_t *needSize,RpcParamData_t *pData) {
 	RpcResult_t ret = RPC_SUCCESS;RpcParamSpec_t *pSpec;
+	uint32_t enableLength;uint32_t temp;
 
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "STEP1");	
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "STEP1");
 	if(inSize < sizeof(RpcParamSpec_t)) {
 		*needSize = 0;
 		return RPC_PARAM_ERROR;
 	}
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "STEP2");	
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "STEP2");
 	pSpec = (RpcParamSpec_t*)inData;
+#ifdef	RPC_CHECK_BYTEORDER
+	IPC_convertHostByteOrder((void*)&(pSpec->paramType),(void*)&temp,sizeof(pSpec->paramType));
+	pSpec->paramType = temp;
+	IPC_convertHostByteOrder((void*)&(pSpec->paramLeng),(void*)&temp,sizeof(pSpec->paramType));
+	pSpec->paramLeng = temp;
+#endif	/* RPC_CHECK_BYTEORDER */
 	switch(pSpec->paramType) {
 	case RPC_INT_TYPE:
+		enableLength = IPC_ENABLE_INT_TYPE_LENGTH;
+		temp = pSpec->paramLeng; break;
 	case RPC_UINT_TYPE:
+		enableLength = IPC_ENABLE_UINT_TYPE_LENGTH;
+		temp = pSpec->paramLeng; break;
 	case RPC_FLOAT_TYPE:
+		enableLength = IPC_ENABLE_FLOAT_TYPE_LENGTH;
+		temp = pSpec->paramLeng; break;
 	case RPC_STRING_TYPE:
+		enableLength = IPC_ENABLE_STRING_TYPE_LENGTH;
+		temp = pSpec->paramLeng+1; break;
 	case RPC_ENUM_TYPE:
-	case RPC_OTHER_TYPE:
+		enableLength = IPC_ENABLE_ENUM_TYPE_LENGTH;
+		temp = pSpec->paramLeng; break;
+	case RPC_OCTET_ARRAY_TYPE:
+		enableLength = IPC_ENABLE_OCTET_ARRAY_TYPE_LENGTH;
+		temp = pSpec->paramLeng; break;
 	case RPC_TYPE_UNKNOWN:
-//		(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "TYPE:%s",IPC_ConvertTypeToString(pSpec->paramType));	
-		break;
+		enableLength = IPC_ENABLE_UNKNOWN_TYPE_LENGTH;
+		temp = pSpec->paramLeng; break;
+	case RPC_BOOLEAN_TYPE:
+		enableLength = IPC_ENABLE_BOOLEAN_TYPE_LENGTH;
+		temp = pSpec->paramLeng; break;
+	case RPC_REFERENCE_TYPE:
+		enableLength = IPC_ENABLE_REFERENCE_TYPE_LENGTH;
+		temp = pSpec->paramLeng; break;
 	default:
 		*needSize = 0;
 		return RPC_PARAM_ERROR;
 	}
+	if(IPC_checkParamLength(pSpec->paramLeng,enableLength) != RPC_SUCCESS) {
+		*needSize = 0;
+		return RPC_PARAM_ERROR;
+	}
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "TYPE:%s",IPC_ConvertTypeToString(pSpec->paramType));
 	(void)memcpy((void*)pData,(void*)pSpec,sizeof(RpcParamSpec_t));
-	*needSize = sizeof(RpcParamSpec_t) + IPC_ALIGNMENT(pSpec->paramLeng);
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "inSize:%d; NeedSize:%d TYPE:%s; LENG:%d;",inSize,*needSize,IPC_ConvertTypeToString(pData->paramSpec.paramType),pData->paramSpec.paramLeng);	
+	*needSize = sizeof(RpcParamSpec_t) + IPC_ALIGNMENT(temp);
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "inSize:%d; NeedSize:%d TYPE:%s; LENG:%d;",inSize,*needSize,IPC_ConvertTypeToString(pData->paramSpec.paramType),pData->paramSpec.paramLeng);
 	if(inSize < *needSize) {
 		*needSize = 0;
 		return RPC_PARAM_ERROR;
 	}
 	pData->paramData = (void*)&(((uint8_t*)inData)[sizeof(RpcParamSpec_t)]);
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "paramData:0x%x",pData->paramData);	
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "paramData:0x%x",pData->paramData);
 	return ret;
 }
 
+#ifdef	RPC_CHECK_BYTEORDER
+static void IPC_convertNetworkByteOrder(void *inData,void *outData,uint32_t size) {
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG3, "IN IPC_convertNetworkByteOrder inData:0x%x; outData:0x%x; size:%d;",inData,outData,size);
+#ifdef	__BIG_ENDIAN__
+	if(size > 0) {
+		(void)memcpy((void*)outData,(void*)inData,size);
+	}
+#else	/* __BIG_ENDIAN__ */
+	{int i;
+	switch(size) {
+	case 0:
+		break;
+	case 1:
+		*((uint8_t*)outData) = *((uint8_t*)inData);
+		break;
+	case 2:
+		*((uint16_t*)outData) = htons(*((uint16_t*)inData));
+		break;
+	case 4:
+		*((uint32_t*)outData) = htonl(*((uint32_t*)inData));
+		break;
+	case 8:
+		for(i = 0;i<8;i++) {
+			((uint8_t*)outData)[i] = ((uint8_t*)inData)[7-i];
+		}
+		break;
+	case 16:
+		for(i = 0;i<16;i++) {
+			((uint8_t*)outData)[i] = ((uint8_t*)inData)[15-i];
+		}
+		break;
+	default:
+		break;
+	}
+	}
+#endif	/* __BIG_ENDIAN__ */
+//	RPC_MemDump(inData,size," -- IN DUMP --");
+//	RPC_MemDump(outData,size," --OUT DUMP --");
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG3, "OUT IPC_convertNetworkByteOrder ");
+}
+
+static void IPC_convertHostByteOrder(void *inData,void *outData,uint32_t size) {
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG3, "IN IPC_convertHostByteOrder inData:0x%x; outData:0x%x; size:%d;",inData,outData,size);
+#ifdef	__BIG_ENDIAN__
+	if(size > 0) {
+		(void)memcpy((void*)outData,(void*)inData,size);
+	}
+#else	/* __BIG_ENDIAN__ */
+	{int i;
+	switch(size) {
+	case 0:
+		break;
+	case 1:
+		*((uint8_t*)outData) = *((uint8_t*)inData);
+		break;
+	case 2:
+		*((uint16_t*)outData) = ntohs(*((uint16_t*)inData));
+		break;
+	case 4:
+		*((uint32_t*)outData) = ntohl(*((uint32_t*)inData));
+		break;
+	case 8:
+		for(i = 0;i<8;i++) {
+			((uint8_t*)outData)[i] = ((uint8_t*)inData)[7-i];
+		}
+		break;
+	case 16:
+		for(i = 0;i<16;i++) {
+			((uint8_t*)outData)[i] = ((uint8_t*)inData)[15-i];
+		}
+		break;
+	default:
+		(void)memcpy((void*)outData,(void*)inData,size);
+		break;
+	}
+	}
+#endif	/* __BIG_ENDIAN__ */
+//	RPC_MemDump(inData,size," -- IN DUMP --");
+//	RPC_MemDump(outData,size," --OUT DUMP --");
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG3, "OUT IPC_convertHostByteOrder ");
+}
+#endif	/* RPC_CHECK_BYTEORDER */
+
 /* ----- TEST Functions ----- */
 
 uint8_t *IPC_ConvertTypeToString(RpcParamType_t type) {
@@ -349,10 +593,14 @@ uint8_t *IPC_ConvertTypeToString(RpcParamType_t type) {
 		return (uint8_t*)"STRING";
 	case RPC_ENUM_TYPE:
 		return (uint8_t*)"ENUM  ";
-	case RPC_OTHER_TYPE:
-		return (uint8_t*)"OTHER ";
+	case RPC_OCTET_ARRAY_TYPE:
+		return (uint8_t*)"OCTARY";
 	case RPC_TYPE_UNKNOWN:
 		return (uint8_t*)"UNKNWN";
+	case RPC_BOOLEAN_TYPE:
+		return (uint8_t*)"BOOLEN";
+	case RPC_REFERENCE_TYPE:
+		return (uint8_t*)"REFRNC";
 	default:
 		return (uint8_t*)"ERROR ";
 	}
@@ -367,6 +615,71 @@ void IPC_DumpParamData(RpcParamData_t *pData) {
 		fprintf(stdout," TYPE:%s LENG:%d DATA-P:0x%x\n",(char*)IPC_ConvertTypeToString(pData->paramSpec.paramType),pData->paramSpec.paramLeng,(uint32_t)pData->paramData);
 		sprintf(lData,"NUM:%d; TYPE:%s",i,IPC_ConvertTypeToString(pData->paramSpec.paramType));
 		RPC_MemDump(pData->paramData,pData->paramSpec.paramLeng,lData);
+		switch(pData->paramSpec.paramType) {
+		case RPC_INT_TYPE:
+			switch(pData->paramSpec.paramLeng) {
+			case 1:
+				fprintf(stdout,"  VAL:%d;\n",*((int8_t*)(pData->paramData)));
+				break;
+			case 2:
+				fprintf(stdout,"  VAL:%d;\n",*((int16_t*)(pData->paramData)));
+				break;
+			case 4:
+				fprintf(stdout,"  VAL:%d;\n",*((int32_t*)(pData->paramData)));
+				break;
+			case 8:
+				fprintf(stdout,"  VAL:%Ld;\n",*((int64_t*)(pData->paramData)));
+				break;
+			}
+			break;
+		case RPC_UINT_TYPE:
+			switch(pData->paramSpec.paramLeng) {
+			case 1:
+				fprintf(stdout,"  VAL:%d;\n",*((uint8_t*)(pData->paramData)));
+				break;
+			case 2:
+				fprintf(stdout,"  VAL:%d;\n",*((uint16_t*)(pData->paramData)));
+				break;
+			case 4:
+				fprintf(stdout,"  VAL:%d;\n",*((uint32_t*)(pData->paramData)));
+				break;
+			case 8:
+				fprintf(stdout,"  VAL:%Ld;\n",*((uint64_t*)(pData->paramData)));
+				break;
+			}
+			break;
+		case RPC_FLOAT_TYPE:
+			switch(pData->paramSpec.paramLeng) {
+			case 4:
+				fprintf(stdout,"  VAL:%e;\n",*((float*)(pData->paramData)));
+				break;
+			case 8:
+				fprintf(stdout,"  VAL:%le;\n",*((double*)(pData->paramData)));
+				break;
+			case 16:
+				fprintf(stdout,"  VAL:%Le;\n",*((long double*)(pData->paramData)));
+				break;
+			}
+			break;
+		case RPC_ENUM_TYPE:
+			fprintf(stdout,"  VAL:0x%x;\n",*((uint32_t*)(pData->paramData)));
+			break;
+		case RPC_BOOLEAN_TYPE:
+			fprintf(stdout,"  VAL:%s;\n", (*((uint8_t*)(pData->paramData)))?"TRUE":"FALSE");
+			break;
+		case RPC_REFERENCE_TYPE:
+			switch(pData->paramSpec.paramLeng) {
+			case 8:
+				fprintf(stdout,"  VAL:0:%Lx;\n",(uint64_t)(*((uint64_t*)(pData->paramData))));
+				break;
+			case 16:
+				fprintf(stdout,"  VAL:%Lx:%Lx;\n",(uint64_t)(*((uint32_t*)(pData->paramData))),(uint64_t)(*(((uint64_t*)(pData->paramData))+1)));
+				break;
+			}
+			break;
+		default:
+			break;
+		}
 		pData++;i++;
 	}
 	fprintf(stdout," TYPE:%s LENG:%d DATA-P:0x%x\n",(char*)IPC_ConvertTypeToString(pData->paramSpec.paramType),pData->paramSpec.paramLeng,(uint32_t)pData->paramData);
@@ -379,15 +692,23 @@ void IPC_DumpParamData(RpcParamData_t *pData) {
 RpcResult_t marshalTest(void);
 
 RpcResult_t marshalTest(void) {
-	RpcResult_t ret;RpcParamData_t pData[11];
-//	RpcParamData_t oData[20];
+	RpcResult_t ret;RpcParamData_t pData[14];
+	RpcParamData_t *oData;
 	int i;
 	uint8_t *marshalData;void *shmData;uint32_t marshalSize;
-	int8_t data0 = 1;uint16_t data1 = 2;int32_t data2 = -1;uint64_t data3 = 3;
-	float data4 = 4.1;double data5 = 5.2;char *data6 = "abcdefghijklmn";
+	int8_t data0 = 1;uint16_t data1 = 2;
+	int32_t data2 = -1;uint64_t data3 = 3;
+	float data4 = -118.625;double data5 = 118.625;
+	char *data6 = "abcdefghijklmn";
 	RpcParamType_t data7 = RPC_ENUM_TYPE;
-	uint8_t data8[128] = {0};uint8_t *data9;
+	uint8_t data8[128] = {0};
+//	uint8_t *data9;
+	uint8_t data9[8];uint8_t *data9P;uint64_t data9Temp;
 	uint32_t unmarshalData[10*1024];
+	RpcBool_t data10 = RPC_TRUE;
+	RpcBool_t data11 = RPC_FALSE;
+	long double data12 = -118.625L;
+	double data12X = (double)data12;
 
 	fprintf(stdout,"@@@@@ NOW START MARSHAL TEST @@@@\n");
 #if	0
@@ -436,9 +757,14 @@ RpcResult_t marshalTest(void) {
 	for(i = 0;i < 128;i++) {
 		data8[i] = 128 -i;
 	}
-	data9 = (uint8_t*)shmData;
+	data9Temp = (uint64_t)((uint8_t*)shmData)&0x00000000FFFFFFFF;
+	for(i = 0;i < 8;i++) {
+		data9[i] = (uint8_t)(data9Temp>>(i*8));
+	}
+//	data9 = (uint8_t*)shmData;
+	data9P = shmData;
 	for(i = 0;i < 2000;i++) {
-		data9[i] = i;
+		data9P[i] = i;
 	}
 	fprintf(stdout,"@@@ SET DATA @@\n");
 	pData[0].paramSpec.paramType = RPC_INT_TYPE;pData[0].paramSpec.paramLeng = 1;pData[0].paramData = (uint8_t*)&data0;
@@ -447,11 +773,20 @@ RpcResult_t marshalTest(void) {
 	pData[3].paramSpec.paramType = RPC_UINT_TYPE;pData[3].paramSpec.paramLeng = 8;pData[3].paramData = (uint8_t*)&data3;
 	pData[4].paramSpec.paramType = RPC_FLOAT_TYPE;pData[4].paramSpec.paramLeng = 4;pData[4].paramData = (uint8_t*)&data4;
 	pData[5].paramSpec.paramType = RPC_FLOAT_TYPE;pData[5].paramSpec.paramLeng = 8;pData[5].paramData = (uint8_t*)&data5;
-	pData[6].paramSpec.paramType = RPC_STRING_TYPE;pData[6].paramSpec.paramLeng = 15;pData[6].paramData = (uint8_t*)data6;
+	pData[6].paramSpec.paramType = RPC_STRING_TYPE;pData[6].paramSpec.paramLeng = strlen(data6);;pData[6].paramData = (uint8_t*)data6;
 	pData[7].paramSpec.paramType = RPC_ENUM_TYPE;pData[7].paramSpec.paramLeng = 4;pData[7].paramData = (uint8_t*)&data7;
-	pData[8].paramSpec.paramType = RPC_OTHER_TYPE;pData[8].paramSpec.paramLeng = 128;pData[8].paramData = (uint8_t*)data8;
-	pData[9].paramSpec.paramType = RPC_OTHER_TYPE;pData[9].paramSpec.paramLeng = 4;pData[9].paramData = (uint8_t*)&data9;
-	pData[10].paramSpec.paramType = RPC_TYPE_UNKNOWN;pData[10].paramSpec.paramLeng = 0;pData[10].paramData = (uint8_t*)NULL;
+	pData[8].paramSpec.paramType = RPC_OCTET_ARRAY_TYPE;pData[8].paramSpec.paramLeng = 128;pData[8].paramData = (uint8_t*)data8;
+	pData[9].paramSpec.paramType = RPC_REFERENCE_TYPE;pData[9].paramSpec.paramLeng = 8;pData[9].paramData = (uint8_t*)&data9;
+	pData[10].paramSpec.paramType = RPC_BOOLEAN_TYPE;pData[10].paramSpec.paramLeng = 1;pData[10].paramData = (uint8_t*)&data10;
+	pData[11].paramSpec.paramType = RPC_BOOLEAN_TYPE;pData[11].paramSpec.paramLeng = 1;pData[11].paramData = (uint8_t*)&data11;
+#ifdef	IEEE754_LONG_DOUBLE_BIAS
+	pData[12].paramSpec.paramType = RPC_FLOAT_TYPE;pData[12].paramSpec.paramLeng = 16;
+	pData[12].paramData = (uint8_t*)&data12;
+#else	/* IEEE754_LONG_DOUBLE_BIAS */
+	pData[12].paramSpec.paramType = RPC_FLOAT_TYPE;pData[12].paramSpec.paramLeng = 8;
+	pData[12].paramData = (uint8_t*)&data12X;
+#endif	/* IEEE754_LONG_DOUBLE_BIAS */
+	pData[13].paramSpec.paramType = RPC_TYPE_UNKNOWN;pData[13].paramSpec.paramLeng = 0;pData[13].paramData = (uint8_t*)NULL;
 	fprintf(stdout,"\n\n@@@ BEFORE MARSHAL DATA @@@\n");
 	IPC_DumpParamData(pData);
 	RPC_MemDump((uint8_t*)(*((uint32_t*)(pData[9].paramData))),2000,"## SHM MEM DATA ##");
@@ -477,6 +812,7 @@ RpcResult_t marshalTest(void) {
 		return ret;							
 	}
 	fprintf(stdout,"\n\n@@@ AFTER UNMARSHAL DATA @@@\n");
+//	oData = (RpcParamData_t*)unmarshalData;
 	IPC_DumpParamData((RpcParamData_t*)unmarshalData);
 	RPC_MemDump((uint8_t*)(*((uint32_t*)((RpcParamData_t*)unmarshalData)[9].paramData)),2000,"## SHM MEM DATA ##");
 	IPC_FreeShmMem(IpcMarshalDataSharedMemId, shmData);
