@@ -1462,10 +1462,9 @@ static RpcResult_t localQueTest(void) {
 #if	0
 	for(;;) {
 		sTime = getSleepTime();
-		sleepTime.tv_sec = sTime/1000;
-		sleepTime.tv_usec = (sTime%1000) * 1000;
-		if((ret = RPC_TaskSleep(&sleepTime,NULL,&errCode)) != RPC_SUCCESS) {
-			(void)RPC_LogPrint(RPC_LOG_MODULE_MSG_QUE,RPC_LOG_LEVEL_FATAL,"ERROR IN Sleep:%s; errCode:%d;",RPC_LogConvertResultCode(ret),errCode);
+		RPC_ConvertTimeoutToTimeval(sTime,&sleepTime);
+		if((ret = RPC_TaskSleep(&sleepTime,NULL)) != RPC_SUCCESS) {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_MSG_QUE,RPC_LOG_LEVEL_FATAL,"ERROR IN Sleep:%s;",RPC_LogConvertResultCode(ret));
 			return ret;
 		}
 	}
@@ -1478,7 +1477,7 @@ static void *queTestSendTask(void *param) {
 	uint32_t queId;RpcBool_t onOff;uint32_t timeout;
 	uint32_t msgId = 0;RpcMsgParam_t msgParam;int i;
 	uint32_t pid;RpcResult_t ret = RPC_SUCCESS;
-	uint32_t sTime;struct timeval sleepTime;uint32_t errCode;
+	uint32_t sTime;struct timeval sleepTime;
 
 	pid = getpid();
 	queId = *((uint32_t*)param);
@@ -1488,7 +1487,7 @@ static void *queTestSendTask(void *param) {
 		sleepTime.tv_sec = sTime/10000;
 		sleepTime.tv_usec = (sTime%10000) * 1000;
 		(void)RPC_LogPrint(RPC_LOG_MODULE_MSG_QUE,RPC_LOG_LEVEL_DEBUG1,"NOW SLEEP SEND TASK TIME:%d.%d;",sleepTime.tv_sec,sleepTime.tv_usec);
-		(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+		(void)RPC_TaskSleep(&sleepTime,NULL);
 		onOff = getOnOff();
 		timeout = getSleepTime();
 		if(ret == RPC_SUCCESS) {
@@ -1542,7 +1541,7 @@ static void *queTestSendTask(void *param) {
 
 static void *queTestRecvTask(void *param) {
 	uint32_t queId;RpcResult_t ret;uint32_t msgId;RpcMsgParam_t msgParam;uint32_t timeout;
-	uint32_t sTime;struct timeval sleepTime;uint32_t errCode;RpcBool_t flag = RPC_TRUE;
+	uint32_t sTime;struct timeval sleepTime;;RpcBool_t flag = RPC_TRUE;
 
 	queId = *((uint32_t*)param);
 	(void)RPC_LogPrint(RPC_LOG_MODULE_MSG_QUE,RPC_LOG_LEVEL_DEBUG1,"NOW START TEST TASK FOR RECV MSG TO QUE:0x%x;",queId);
@@ -1552,7 +1551,7 @@ static void *queTestRecvTask(void *param) {
 			sleepTime.tv_sec = sTime/2000;
 			sleepTime.tv_usec = (sTime%2000) * 1000;
 			(void)RPC_LogPrint(RPC_LOG_MODULE_MSG_QUE,RPC_LOG_LEVEL_DEBUG1,"NOW SLEEP RECV TASK TIME:%d.%d;",sleepTime.tv_sec,sleepTime.tv_usec);
-			(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+			(void)RPC_TaskSleep(&sleepTime,NULL);
 			timeout = getSleepTime();
 			if((ret = IPC_GetMsgFromQue(queId,&msgId,&msgParam,timeout))!= RPC_SUCCESS) {
 				if(ret == RPC_TIMEOUT_ERROR) {
