@@ -79,6 +79,8 @@ typedef struct {
 #endif	/* USE_DOUBLE_TASK_CNTL */
 	RpcMutexID_t mutexId;
 	RpcMutexAttribute_t mutexAttr;
+	RpcCondID_t condId;
+	RpcCondAttribute_t condAttr;
 } IpcRendezvEntry_t;
 
 static int32_t IpcRendezvSharedMemId = -1;
@@ -227,7 +229,7 @@ extern RpcResult_t IPC_DestoryRendezv(uint32_t rendezvId) {
 }
 
 extern RpcResult_t IPC_RendezvSend(uint32_t rendezvId, RpcTaskID_t recvTask,void *sendData, uint32_t sendSize,void **replyData, uint32_t *replySize, uint32_t timeOut) {
-	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret;
+	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret1,ret2;
 	RpcBool_t waitForever;struct timespec specTime;uint32_t myPid;
 #ifdef	USE_CANCEL_TASK
 	int oldstate;
@@ -250,28 +252,40 @@ extern RpcResult_t IPC_RendezvSend(uint32_t rendezvId, RpcTaskID_t recvTask,void
 		}
 	}
 	myPid = RPC_GetPid();
-	if((ret = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
+	if((ret1 = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
 		if(rep->rendezvState == IPC_RENDEZV_STATE_READY) rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
-		(void)RPC_MutexUnlock(&(rep->mutexId));
-		return ret;
+		return ret1;
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(PTHREAD_CANCEL_DISABLE,&oldstate);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = IPC_rendezvSendState(rep,myPid, recvTask,sendData, sendSize,waitForever,&specTime)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS SEND STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret1 = IPC_rendezvSendState(rep,myPid, recvTask,sendData, sendSize,waitForever,&specTime)) != RPC_SUCCESS) {
+		if(ret1 == RPC_TIMEOUT_ERROR)
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS SEND STATE ");
+		else {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS SEND STATE RET:%s;",RPC_LogConvertResultCode(ret1));
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			return ret1;
+		}
 	}
-	if((ret = IPC_rendezvPostSendState(rep,replyData,replySize)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST SEND STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret2 = IPC_rendezvPostSendState(rep,replyData,replySize)) != RPC_SUCCESS) {
+		if(ret1 == RPC_SUCCESS) {
+			if(ret2 == RPC_TIMEOUT_ERROR)
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS POST SEND STATE ");
+			else
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST SEND STATE RET:%s;",RPC_LogConvertResultCode(ret2));
+		}
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(oldstate,(int*)NULL);
 #endif	/* USE_CANCEL_TASK */
-	return ret;
+	return ret2;
 }
 
 extern RpcResult_t IPC_RendezvSendByTask(RpcBool_t IpcFlag, RpcTaskID_t recvTask,void *sendData, uint32_t sendSize,void **replyData, uint32_t *replySize, uint32_t timeOut) {
-	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret;
+	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret1,ret2;
 	RpcBool_t waitForever;struct timespec specTime;uint32_t rendezvId;
 	uint32_t myPid;
 #ifdef	USE_CANCEL_TASK
@@ -284,8 +298,8 @@ extern RpcResult_t IPC_RendezvSendByTask(RpcBool_t IpcFlag, RpcTaskID_t recvTask
 			return RPC_PARAM_ERROR;
 		}
 		else if((rep = IPC_searchRendezvEntryByRecvTask(IpcFlag,myPid, recvTask,rcp)) == (IpcRendezvEntry_t*)NULL) {
-			if((ret = IPC_allocRendezvResource(IpcFlag,rcp,&rendezvId)) != RPC_SUCCESS) {
-				return ret;
+			if((ret1 = IPC_allocRendezvResource(IpcFlag,rcp,&rendezvId)) != RPC_SUCCESS) {
+				return ret1;
 			}
 			else if((rep = IPC_searchRendezvEntryByRendezvId(IpcFlag,rendezvId,rcp)) == (IpcRendezvEntry_t*)NULL) {
 				return RPC_FATAL_ERROR;
@@ -297,36 +311,48 @@ extern RpcResult_t IPC_RendezvSendByTask(RpcBool_t IpcFlag, RpcTaskID_t recvTask
 			return RPC_PARAM_ERROR;
 		}
 		else if((rep = IPC_searchRendezvEntryByRecvTask(IpcFlag,myPid, recvTask,rcp)) == (IpcRendezvEntry_t*)NULL) {
-			if((ret = IPC_allocRendezvResource(IpcFlag,rcp,&rendezvId)) != RPC_SUCCESS) {
-				return ret;
+			if((ret1 = IPC_allocRendezvResource(IpcFlag,rcp,&rendezvId)) != RPC_SUCCESS) {
+				return ret1;
 			}
 			else if((rep = IPC_searchRendezvEntryByRendezvId(IpcFlag,rendezvId,rcp)) == (IpcRendezvEntry_t*)NULL) {
 				return RPC_FATAL_ERROR;
 			}
 		}
 	}
-	if((ret = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
+	if((ret1 = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
 		if(rep->rendezvState == IPC_RENDEZV_STATE_READY) rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
-		(void)RPC_MutexUnlock(&(rep->mutexId));
-		return ret;
+		return ret1;
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(PTHREAD_CANCEL_DISABLE,&oldstate);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = IPC_rendezvSendState(rep,myPid, recvTask,sendData, sendSize,waitForever,&specTime)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS SEND STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret1 = IPC_rendezvSendState(rep,myPid, recvTask,sendData, sendSize,waitForever,&specTime)) != RPC_SUCCESS) {
+		if(ret1 == RPC_TIMEOUT_ERROR)
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS SEND STATE ");
+		else {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS SEND STATE RET:%s;",RPC_LogConvertResultCode(ret1));
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			return ret1;
+		}
 	}
-	if((ret = IPC_rendezvPostSendState(rep,replyData,replySize)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST SEND STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret2 = IPC_rendezvPostSendState(rep,replyData,replySize)) != RPC_SUCCESS) {
+		if(ret1 == RPC_SUCCESS) {
+			if(ret2 == RPC_TIMEOUT_ERROR)
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS POST SEND STATE ");
+			else
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST SEND STATE RET:%s;",RPC_LogConvertResultCode(ret2));
+		}
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(oldstate,(int*)NULL);
 #endif	/* USE_CANCEL_TASK */
-	return ret;
+	return ret2;
 }
 
 extern RpcResult_t IPC_RendezvSendExt(uint32_t rendezvId, uint32_t recvPid, RpcTaskID_t recvTask,void *sendData, uint32_t sendSize,void **replyData, uint32_t *replySize, uint32_t timeOut) {
-	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret;
+	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret1,ret2;
 	RpcBool_t waitForever;struct timespec specTime;uint32_t myPid;
 #ifdef	USE_CANCEL_TASK
 	int oldstate;
@@ -355,28 +381,40 @@ extern RpcResult_t IPC_RendezvSendExt(uint32_t rendezvId, uint32_t recvPid, RpcT
 			return RPC_PARAM_ERROR;
 		}
 	}
-	if((ret = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
+	if((ret1 = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
 		if(rep->rendezvState == IPC_RENDEZV_STATE_READY) rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
-		(void)RPC_MutexUnlock(&(rep->mutexId));
-		return ret;
+		return ret1;
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(PTHREAD_CANCEL_DISABLE,&oldstate);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = IPC_rendezvSendState(rep,recvPid, recvTask,sendData, sendSize,waitForever,&specTime)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS SEND STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret1 = IPC_rendezvSendState(rep,recvPid, recvTask,sendData, sendSize,waitForever,&specTime)) != RPC_SUCCESS) {
+		if(ret1 == RPC_TIMEOUT_ERROR)
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS SEND STATE ");
+		else {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS SEND STATE RET:%s;",RPC_LogConvertResultCode(ret1));
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			return ret1;
+		}
 	}
-	if((ret = IPC_rendezvPostSendState(rep,replyData,replySize)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST SEND STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret2 = IPC_rendezvPostSendState(rep,replyData,replySize)) != RPC_SUCCESS) {
+		if(ret1 == RPC_SUCCESS) {
+			if(ret2 == RPC_TIMEOUT_ERROR)
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS POST SEND STATE ");
+			else
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST SEND STATE RET:%s;",RPC_LogConvertResultCode(ret2));
+		}
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(oldstate,(int*)NULL);
 #endif	/* USE_CANCEL_TASK */
-	return ret;
+	return ret2;
 }
 
 extern RpcResult_t IPC_RendezvSendExtByTask(RpcBool_t IpcFlag, uint32_t recvPid, RpcTaskID_t recvTask,void *sendData, uint32_t sendSize,void **replyData, uint32_t *replySize, uint32_t timeOut) {
-	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret;
+	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret1,ret2;
 	RpcBool_t waitForever;struct timespec specTime;uint32_t rendezvId;
 	uint32_t myPid;
 #ifdef	USE_CANCEL_TASK
@@ -388,8 +426,8 @@ extern RpcResult_t IPC_RendezvSendExtByTask(RpcBool_t IpcFlag, uint32_t recvPid,
 			return RPC_PARAM_ERROR;
 		}
 		else if((rep = IPC_searchRendezvEntryByRecvTask(IpcFlag,recvPid, recvTask,rcp)) == (IpcRendezvEntry_t*)NULL) {
-			if((ret = IPC_allocRendezvResource(IpcFlag,rcp,&rendezvId)) != RPC_SUCCESS) {
-				return ret;
+			if((ret1 = IPC_allocRendezvResource(IpcFlag,rcp,&rendezvId)) != RPC_SUCCESS) {
+				return ret1;
 			}
 			else if((rep = IPC_searchRendezvEntryByRendezvId(IpcFlag,rendezvId,rcp)) == (IpcRendezvEntry_t*)NULL) {
 				return RPC_FATAL_ERROR;
@@ -405,36 +443,48 @@ extern RpcResult_t IPC_RendezvSendExtByTask(RpcBool_t IpcFlag, uint32_t recvPid,
 			return RPC_PARAM_ERROR;
 		}
 		else if((rep = IPC_searchRendezvEntryByRecvTask(IpcFlag,recvPid, recvTask,rcp)) == (IpcRendezvEntry_t*)NULL) {
-			if((ret = IPC_allocRendezvResource(IpcFlag,rcp,&rendezvId)) != RPC_SUCCESS) {
-				return ret;
+			if((ret1 = IPC_allocRendezvResource(IpcFlag,rcp,&rendezvId)) != RPC_SUCCESS) {
+				return ret1;
 			}
 			else if((rep = IPC_searchRendezvEntryByRendezvId(IpcFlag,rendezvId,rcp)) == (IpcRendezvEntry_t*)NULL) {
 				return RPC_FATAL_ERROR;
 			}
 		}
 	}
-	if((ret = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
+	if((ret1 = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
 		if(rep->rendezvState == IPC_RENDEZV_STATE_READY) rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
-		(void)RPC_MutexUnlock(&(rep->mutexId));
-		return ret;
+		return ret1;
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(PTHREAD_CANCEL_DISABLE,&oldstate);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = IPC_rendezvSendState(rep,recvPid, recvTask,sendData, sendSize,waitForever,&specTime)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS SEND STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret1 = IPC_rendezvSendState(rep,recvPid, recvTask,sendData, sendSize,waitForever,&specTime)) != RPC_SUCCESS) {
+		if(ret1 == RPC_TIMEOUT_ERROR)
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS SEND STATE ");
+		else {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS SEND STATE RET:%s;",RPC_LogConvertResultCode(ret1));
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			return ret1;
+		}
 	}
-	if((ret = IPC_rendezvPostSendState(rep,replyData,replySize)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST SEND STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret2 = IPC_rendezvPostSendState(rep,replyData,replySize)) != RPC_SUCCESS) {
+		if(ret1 == RPC_SUCCESS) {
+			if(ret2 == RPC_TIMEOUT_ERROR)
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS POST SEND STATE ");
+			else
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST SEND STATE RET:%s;",RPC_LogConvertResultCode(ret2));
+		}
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(oldstate,(int*)NULL);
 #endif	/* USE_CANCEL_TASK */
-	return ret;
+	return ret2;
 }
 
 extern RpcResult_t IPC_RendezvSendByRendezvId(uint32_t rendezvId, void *sendData, uint32_t sendSize,void **replyData, uint32_t *replySize, uint32_t timeOut) {
-	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret;
+	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret1,ret2;
 	RpcBool_t waitForever;struct timespec specTime;
 #ifdef	USE_CANCEL_TASK
 	int oldstate;
@@ -458,35 +508,48 @@ extern RpcResult_t IPC_RendezvSendByRendezvId(uint32_t rendezvId, void *sendData
 			return RPC_PARAM_ERROR;
 		}
 	}
-	if((ret = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
+	if((ret1 = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
 		if(rep->rendezvState == IPC_RENDEZV_STATE_READY) rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
-		(void)RPC_MutexUnlock(&(rep->mutexId));
-		return ret;
+		return ret1;
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(PTHREAD_CANCEL_DISABLE,&oldstate);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = IPC_rendezvSendState(rep,0,(RpcTaskID_t)0,sendData, sendSize,waitForever,&specTime)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS SEND STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret1 = IPC_rendezvSendState(rep,0, (RpcTaskID_t)0,sendData, sendSize,waitForever,&specTime)) != RPC_SUCCESS) {
+		if(ret1 == RPC_TIMEOUT_ERROR)
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS SEND STATE ");
+		else {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS SEND STATE RET:%s;",RPC_LogConvertResultCode(ret1));
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			return ret1;
+		}
 	}
-	if((ret = IPC_rendezvPostSendState(rep,replyData,replySize)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST SEND STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret2 = IPC_rendezvPostSendState(rep,replyData,replySize)) != RPC_SUCCESS) {
+		if(ret1 == RPC_SUCCESS) {
+			if(ret2 == RPC_TIMEOUT_ERROR)
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS POST SEND STATE ");
+			else
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST SEND STATE RET:%s;",RPC_LogConvertResultCode(ret2));
+		}
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(oldstate,(int*)NULL);
 #endif	/* USE_CANCEL_TASK */
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_DEBUG1,"OUT IPC_RendezvSendByRendezvId replyData:0x%x; replySize:%d; RET:%s;",
 //		*replyData,*replySize,RPC_LogConvertResultCode(ret));
-	return ret;
+	return ret2;
 }
 
 extern RpcResult_t IPC_RendezvRecv(uint32_t rendezvId, RpcTaskID_t sendTask, void **recvData, uint32_t *recvSize, uint32_t timeOut) {
-	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret;
+	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret1,ret2;
 	RpcBool_t waitForever;struct timespec specTime;uint32_t myPid;
 #ifdef	USE_CANCEL_TASK
 	int oldstate;
 #endif	/* USE_CANCEL_TASK */
 
+Retry:
 	if((rcp = IpcShmRendezvControl) == (IpcRendezvControl_t*)NULL) {
 		if((rcp = IpcLclRendezvControl) == (IpcRendezvControl_t*)NULL) {
 			return RPC_NOT_READY;
@@ -504,41 +567,61 @@ extern RpcResult_t IPC_RendezvRecv(uint32_t rendezvId, RpcTaskID_t sendTask, voi
 		}
 	}
 	myPid = RPC_GetPid();
-	if((ret = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
+	if((ret1 = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
 		if(rep->rendezvState == IPC_RENDEZV_STATE_READY) rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
-		(void)RPC_MutexUnlock(&(rep->mutexId));
-		return ret;
+		return ret1;
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(PTHREAD_CANCEL_DISABLE,&oldstate);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = IPC_rendezvRecvState(rep,myPid, sendTask,waitForever,&specTime)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret1 = IPC_rendezvRecvState(rep,myPid, sendTask,waitForever,&specTime)) != RPC_SUCCESS) {
+		if(ret1 == RPC_TIMEOUT_ERROR)
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS RECEIVE STATE");
+		else if(ret1 == RPC_BUSY_ERROR) {
+//			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," PREVIOUS SESSION WAS NOT STILL FINISHED, SO RETRY");
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			goto Retry;
+		}
+		else {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret1));
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			return ret1;
+		}
 	}
-	if((ret = IPC_rendezvPostRecvState(rep,recvData,recvSize)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret2 = IPC_rendezvPostRecvState(rep,recvData,recvSize)) != RPC_SUCCESS) {
+		if(ret1 == RPC_SUCCESS) {
+			if(ret2 == RPC_TIMEOUT_ERROR)
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING,"TIMEOUT OCCUR IN RENDEZVOUS POST RECEIVE STATE");
+			else
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret2));
+		}
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(oldstate,(int*)NULL);
 #endif	/* USE_CANCEL_TASK */
-	return ret;
+	return ret2;
 }
 
 extern RpcResult_t IPC_RendezvRecvByTask(RpcBool_t IpcFlag, RpcTaskID_t sendTask, uint32_t *rendezvId,void **recvData, uint32_t *recvSize, uint32_t timeOut) {
-	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret;
+	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret1,ret2;
 	RpcBool_t waitForever;struct timespec specTime;uint32_t myPid;
 #ifdef	USE_CANCEL_TASK
 	int oldstate;
 #endif	/* USE_CANCEL_TASK */
 
+Retry:
 	myPid = RPC_GetPid();
 	if(IpcFlag) {
 		if((rcp = IpcShmRendezvControl) == (IpcRendezvControl_t*)NULL) {
 			return RPC_PARAM_ERROR;
 		}
 		else if((rep = IPC_searchRendezvEntryBySendTask(IpcFlag,myPid, sendTask,rcp)) == (IpcRendezvEntry_t*)NULL) {
-			if((ret = IPC_allocRendezvResource(IpcFlag,rcp,rendezvId)) != RPC_SUCCESS) {
-				return ret;
+			if((ret1 = IPC_allocRendezvResource(IpcFlag,rcp,rendezvId)) != RPC_SUCCESS) {
+				return ret1;
 			}
 			else if((rep = IPC_searchRendezvEntryByRendezvId(IpcFlag,*rendezvId,rcp)) == (IpcRendezvEntry_t*)NULL) {
 				return RPC_FATAL_ERROR;
@@ -553,8 +636,8 @@ extern RpcResult_t IPC_RendezvRecvByTask(RpcBool_t IpcFlag, RpcTaskID_t sendTask
 			return RPC_PARAM_ERROR;
 		}
 		else if((rep = IPC_searchRendezvEntryBySendTask(IpcFlag,myPid, sendTask,rcp)) == (IpcRendezvEntry_t*)NULL) {
-			if((ret = IPC_allocRendezvResource(IpcFlag,rcp,rendezvId)) != RPC_SUCCESS) {
-				return ret;
+			if((ret1 = IPC_allocRendezvResource(IpcFlag,rcp,rendezvId)) != RPC_SUCCESS) {
+				return ret1;
 			}
 			else if((rep = IPC_searchRendezvEntryByRendezvId(IpcFlag,*rendezvId,rcp)) == (IpcRendezvEntry_t*)NULL) {
 				return RPC_FATAL_ERROR;
@@ -564,33 +647,53 @@ extern RpcResult_t IPC_RendezvRecvByTask(RpcBool_t IpcFlag, RpcTaskID_t sendTask
 			*rendezvId = rep->rendezvId;
 		}
 	}
-	if((ret = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
+	if((ret1 = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
 		if(rep->rendezvState == IPC_RENDEZV_STATE_READY) rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
-		(void)RPC_MutexUnlock(&(rep->mutexId));
-		return ret;
+		return ret1;
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(PTHREAD_CANCEL_DISABLE,&oldstate);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = IPC_rendezvRecvState(rep,myPid, sendTask,waitForever,&specTime)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret1 = IPC_rendezvRecvState(rep,myPid, sendTask,waitForever,&specTime)) != RPC_SUCCESS) {
+		if(ret1 == RPC_TIMEOUT_ERROR)
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS RECEIVE STATE");
+		else if(ret1 == RPC_BUSY_ERROR) {
+//			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," PREVIOUS SESSION WAS NOT STILL FINISHED, SO RETRY");
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			goto Retry;
+		}
+		else {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret1));
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			return ret1;
+		}
 	}
-	if((ret = IPC_rendezvPostRecvState(rep,recvData,recvSize)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret2 = IPC_rendezvPostRecvState(rep,recvData,recvSize)) != RPC_SUCCESS) {
+		if(ret1 == RPC_SUCCESS) {
+			if(ret2 == RPC_TIMEOUT_ERROR)
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING,"TIMEOUT OCCUR IN RENDEZVOUS POST RECEIVE STATE");
+			else
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret2));
+		}
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(oldstate,(int*)NULL);
 #endif	/* USE_CANCEL_TASK */
-	return ret;
+	return ret2;
 }
 
 extern RpcResult_t IPC_RendezvRecvExt(uint32_t rendezvId, uint32_t sendPid, RpcTaskID_t sendTask, void **recvData, uint32_t *recvSize, uint32_t timeOut) {
-	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret;
+	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret1,ret2;
 	RpcBool_t waitForever;struct timespec specTime;uint32_t myPid;
 #ifdef	USE_CANCEL_TASK
 	int oldstate;
 #endif	/* USE_CANCEL_TASK */
 
+Retry:
 	myPid = RPC_GetPid();
 	if((rcp = IpcShmRendezvControl) == (IpcRendezvControl_t*)NULL) {
 		if((rcp = IpcLclRendezvControl) == (IpcRendezvControl_t*)NULL) {
@@ -614,40 +717,60 @@ extern RpcResult_t IPC_RendezvRecvExt(uint32_t rendezvId, uint32_t sendPid, RpcT
 			return RPC_PARAM_ERROR;
 		}
 	}
-	if((ret = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
+	if((ret1 = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
 		if(rep->rendezvState == IPC_RENDEZV_STATE_READY) rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
-		(void)RPC_MutexUnlock(&(rep->mutexId));
-		return ret;
+		return ret1;
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(PTHREAD_CANCEL_DISABLE,&oldstate);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = IPC_rendezvRecvState(rep,sendPid, sendTask,waitForever,&specTime)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret1 = IPC_rendezvRecvState(rep,sendPid, sendTask,waitForever,&specTime)) != RPC_SUCCESS) {
+		if(ret1 == RPC_TIMEOUT_ERROR)
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS RECEIVE STATE");
+		else if(ret1 == RPC_BUSY_ERROR) {
+//			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," PREVIOUS SESSION WAS NOT STILL FINISHED, SO RETRY");
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			goto Retry;
+		}
+		else {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret1));
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			return ret1;
+		}
 	}
-	if((ret = IPC_rendezvPostRecvState(rep,recvData,recvSize)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret2 = IPC_rendezvPostRecvState(rep,recvData,recvSize)) != RPC_SUCCESS) {
+		if(ret1 == RPC_SUCCESS) {
+			if(ret2 == RPC_TIMEOUT_ERROR)
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING,"TIMEOUT OCCUR IN RENDEZVOUS POST RECEIVE STATE");
+			else
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret2));
+		}
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(oldstate,(int*)NULL);
 #endif	/* USE_CANCEL_TASK */
-	return ret;
+	return ret2;
 }
 
 extern RpcResult_t IPC_RendezvRecvExtByTask(RpcBool_t IpcFlag, uint32_t sendPid, RpcTaskID_t sendTask, uint32_t *rendezvId,void **recvData, uint32_t *recvSize, uint32_t timeOut) {
-	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret;
+	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret1,ret2;
 	RpcBool_t waitForever;struct timespec specTime;uint32_t myPid;
 #ifdef	USE_CANCEL_TASK
 	int oldstate;
 #endif	/* USE_CANCEL_TASK */
 
+Retry:
 	if(IpcFlag) {
 		if((rcp = IpcShmRendezvControl) == (IpcRendezvControl_t*)NULL) {
 			return RPC_PARAM_ERROR;
 		}
 		else if((rep = IPC_searchRendezvEntryBySendTask(IpcFlag,sendPid, sendTask,rcp)) == (IpcRendezvEntry_t*)NULL) {
-			if((ret = IPC_allocRendezvResource(IpcFlag,rcp,rendezvId)) != RPC_SUCCESS) {
-				return ret;
+			if((ret1 = IPC_allocRendezvResource(IpcFlag,rcp,rendezvId)) != RPC_SUCCESS) {
+				return ret1;
 			}
 			else if((rep = IPC_searchRendezvEntryByRendezvId(IpcFlag,*rendezvId,rcp)) == (IpcRendezvEntry_t*)NULL) {
 				return RPC_FATAL_ERROR;
@@ -666,8 +789,8 @@ extern RpcResult_t IPC_RendezvRecvExtByTask(RpcBool_t IpcFlag, uint32_t sendPid,
 			return RPC_PARAM_ERROR;
 		}
 		else if((rep = IPC_searchRendezvEntryBySendTask(IpcFlag,sendPid, sendTask,rcp)) == (IpcRendezvEntry_t*)NULL) {
-			if((ret = IPC_allocRendezvResource(IpcFlag,rcp,rendezvId)) != RPC_SUCCESS) {
-				return ret;
+			if((ret1 = IPC_allocRendezvResource(IpcFlag,rcp,rendezvId)) != RPC_SUCCESS) {
+				return ret1;
 			}
 			else if((rep = IPC_searchRendezvEntryByRendezvId(IpcFlag,*rendezvId,rcp)) == (IpcRendezvEntry_t*)NULL) {
 				return RPC_FATAL_ERROR;
@@ -677,28 +800,47 @@ extern RpcResult_t IPC_RendezvRecvExtByTask(RpcBool_t IpcFlag, uint32_t sendPid,
 			*rendezvId = rep->rendezvId;
 		}
 	}
-	if((ret = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
+	if((ret1 = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
 		if(rep->rendezvState == IPC_RENDEZV_STATE_READY) rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
-		(void)RPC_MutexUnlock(&(rep->mutexId));
-		return ret;
+		return ret1;
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(PTHREAD_CANCEL_DISABLE,&oldstate);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = IPC_rendezvRecvState(rep,sendPid, sendTask,waitForever,&specTime)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret1 = IPC_rendezvRecvState(rep,sendPid, sendTask,waitForever,&specTime)) != RPC_SUCCESS) {
+		if(ret1 == RPC_TIMEOUT_ERROR)
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS RECEIVE STATE");
+		else if(ret1 == RPC_BUSY_ERROR) {
+//			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," PREVIOUS SESSION WAS NOT STILL FINISHED, SO RETRY");
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			goto Retry;
+		}
+		else {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret1));
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			return ret1;
+		}
 	}
-	if((ret = IPC_rendezvPostRecvState(rep,recvData,recvSize)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret2 = IPC_rendezvPostRecvState(rep,recvData,recvSize)) != RPC_SUCCESS) {
+		if(ret1 == RPC_SUCCESS) {
+			if(ret2 == RPC_TIMEOUT_ERROR)
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING,"TIMEOUT OCCUR IN RENDEZVOUS POST RECEIVE STATE");
+			else
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret2));
+		}
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(oldstate,(int*)NULL);
 #endif	/* USE_CANCEL_TASK */
-	return ret;
+	return ret2;
 }
 
 extern RpcResult_t IPC_RendezvRecvByRendezvId(uint32_t rendezvId, void **recvData, uint32_t *recvSize, uint32_t timeOut) {
-	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret;
+	IpcRendezvEntry_t *rep;IpcRendezvControl_t *rcp;RpcResult_t ret1,ret2;
 	RpcBool_t waitForever;struct timespec specTime;
 #ifdef	USE_CANCEL_TASK
 	int oldstate;
@@ -706,6 +848,7 @@ extern RpcResult_t IPC_RendezvRecvByRendezvId(uint32_t rendezvId, void **recvDat
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_DEBUG1,"IN IPC_RendezvRecvByRendezvId rendezvId:0x%x;timeOut:%d;",
 //		rendezvId,timeOut);
+Retry:
 	if((rcp = IpcShmRendezvControl) == (IpcRendezvControl_t*)NULL) {
 		if((rcp = IpcLclRendezvControl) == (IpcRendezvControl_t*)NULL) {
 			return RPC_NOT_READY;
@@ -722,26 +865,45 @@ extern RpcResult_t IPC_RendezvRecvByRendezvId(uint32_t rendezvId, void **recvDat
 			return RPC_PARAM_ERROR;
 		}
 	}
-	if((ret = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
+	if((ret1 = IPC_checkTimeoutForRendezv(timeOut,&waitForever,&specTime)) != RPC_SUCCESS) {
 		if(rep->rendezvState == IPC_RENDEZV_STATE_READY) rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
-		(void)RPC_MutexUnlock(&(rep->mutexId));
-		return ret;
+		return ret1;
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(PTHREAD_CANCEL_DISABLE,&oldstate);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = IPC_rendezvRecvState(rep,0,(RpcTaskID_t)0,waitForever,&specTime)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret1 = IPC_rendezvRecvState(rep,0,(RpcTaskID_t) 0,waitForever,&specTime)) != RPC_SUCCESS) {
+		if(ret1 == RPC_TIMEOUT_ERROR)
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," TIMEOUT OCCUR IN RENDEZVOUS RECEIVE STATE");
+		else if(ret1 == RPC_BUSY_ERROR) {
+//			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING," PREVIOUS SESSION WAS NOT STILL FINISHED, SO RETRY");
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			goto Retry;
+		}
+		else {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret1));
+#ifdef	USE_CANCEL_TASK
+			(void)RPC_SetCancelState(oldstate,(int*)NULL);
+#endif	/* USE_CANCEL_TASK */
+			return ret1;
+		}
 	}
-	if((ret = IPC_rendezvPostRecvState(rep,recvData,recvSize)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret));
+	if((ret2 = IPC_rendezvPostRecvState(rep,recvData,recvSize)) != RPC_SUCCESS) {
+		if(ret1 == RPC_SUCCESS) {
+			if(ret2 == RPC_TIMEOUT_ERROR)
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_WARNING,"TIMEOUT OCCUR IN RENDEZVOUS POST RECEIVE STATE");
+			else
+				(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_ERROR," ERROR IN RENDEZVOUS POST RECEIVE STATE RET:%s;",RPC_LogConvertResultCode(ret2));
+		}
 	}
 #ifdef	USE_CANCEL_TASK
 	(void)RPC_SetCancelState(oldstate,(int*)NULL);
 #endif	/* USE_CANCEL_TASK */
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_DEBUG1,"OUT IPC_RendezvRecvByRendezvId recvData:0x%x; recvSize:%d; RET:%s;",
 //		*recvData,*recvSize,RPC_LogConvertResultCode(ret));
-	return ret;
+	return ret2;
 }
 
 extern RpcResult_t IPC_RendezvReply(uint32_t rendezvId, void *replyData, uint32_t replySize) {
@@ -785,7 +947,7 @@ extern RpcResult_t IPC_RendezvReply(uint32_t rendezvId, void *replyData, uint32_
 /* ----- Internal Functions ----- */
 
 static RpcResult_t IPC_rendezvSendState(IpcRendezvEntry_t *rep,uint32_t recvPid, RpcTaskID_t recvTask,void *sendData, uint32_t sendSize,RpcBool_t waitForever,struct timespec *specTime) {
-	RpcResult_t ret;RpcTaskID_t myTask;struct timeval sleepTime;uint32_t errCode;
+	RpcResult_t ret;RpcTaskID_t myTask;struct timeval sleepTime;
 	uint32_t myPid;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_DEBUG1,"IN IPC_rendezvSendState rep:0x%x; STATE:%d; recvPid:0x%x; recvTask:0x%x, sendData:0x%x; sendSize:%d; waitForever:%d;",
@@ -853,9 +1015,8 @@ static RpcResult_t IPC_rendezvSendState(IpcRendezvEntry_t *rep,uint32_t recvPid,
 #endif	/* USE_DOUBLE_TASK_CNTL */
 		(void)RPC_MutexUnlock(&(rep->mutexId));
 #if	defined(USE_SEMAPHORE)&&(!defined(USE_DOUBLE_TASK_CNTL))
-		sleepTime.tv_sec = 0;
-		sleepTime.tv_usec = IPC_RENDEZV_SLEEP_FOR_SWITCH_TASK*1000;
-		(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+		RPC_ConvertTimeoutToTimeval(IPC_RENDEZV_SLEEP_FOR_SWITCH_TASK,&sleepTime);
+		(void)RPC_TaskSleep(&sleepTime,NULL);
 #endif	/* USE_SEMAPHORE && !USE_DOUBLE_TASK_CNTL */
 //		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_DEBUG2,"NOW WAIT SEND TASK:0x%x",myTask);
 		if(waitForever) {
@@ -906,6 +1067,7 @@ static RpcResult_t IPC_rendezvPostSendState(IpcRendezvEntry_t *rep,void **replyD
 		rep->receiverTask = 0;
 		rep->receiverPid = 0;
 		rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
+		(void)RPC_CondSignal(&(rep->condId));
 		(void)RPC_MutexUnlock(&(rep->mutexId));
 		ret = RPC_SUCCESS;
 		break;
@@ -919,14 +1081,16 @@ static RpcResult_t IPC_rendezvPostSendState(IpcRendezvEntry_t *rep,void **replyD
 		rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
 		*replyData = (void*)NULL;
 		*replySize = 0;
+//		(void)RPC_CondSignal(&(rep->condId));
 		(void)RPC_MutexUnlock(&(rep->mutexId));
-		ret = RPC_INTERUPTTED;
+		ret = RPC_INTERUPTTED;	/* ERROR BUT DATA WAS ALREADY SENT TO RECEIVER */
 		break;
 	case IPC_RENDEZV_STATE_WAIT_GET_DATA:
 	case IPC_RENDEZV_STATE_WAIT_RECEIVER:
 		*replyData = (void*)NULL;
 		*replySize = 0;
 		rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
+//		(void)RPC_CondSignal(&(rep->condId));
 		(void)RPC_MutexUnlock(&(rep->mutexId));
 		ret = RPC_TIMEOUT_ERROR;
 		break;
@@ -934,6 +1098,7 @@ static RpcResult_t IPC_rendezvPostSendState(IpcRendezvEntry_t *rep,void **replyD
 		*replyData = (void*)NULL;
 		*replySize = 0;
 		rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
+//		(void)RPC_CondSignal(&(rep->condId));
 		(void)RPC_MutexUnlock(&(rep->mutexId));
 		ret = RPC_PARAM_ERROR;
 		break;
@@ -1005,6 +1170,14 @@ static RpcResult_t IPC_rendezvRecvState(IpcRendezvEntry_t *rep,uint32_t sendPid,
 		(void)RPC_MutexUnlock(&(rep->mutexId));
 		ret = RPC_SUCCESS;
 		break;
+	case IPC_RENDEZV_STATE_WAIT_END:
+//		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_DEBUG3,"STATE IS IPC_RENDEZV_STATE_WAIT_END SO WAIT");
+		ret = RPC_CondWait(&(rep->condId),&(rep->mutexId));
+//		(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_DEBUG3,"WAKE UP");
+		if(ret == RPC_SUCCESS)
+			ret = RPC_BUSY_ERROR;	/* RETRT RECV */
+		(void)RPC_MutexUnlock(&(rep->mutexId));
+		break;
 	default:
 		if(rep->rendezvState == IPC_RENDEZV_STATE_READY) rep->rendezvState = IPC_RENDEZV_STATE_IDLE;
 		(void)RPC_MutexUnlock(&(rep->mutexId));
@@ -1340,10 +1513,23 @@ static RpcResult_t RPC_createMutexForRendezv(RpcBool_t IpcFlag,IpcRendezvEntry_t
 	if((ret = RPC_InitMutex(&(rep->mutexId),&(rep->mutexAttr))) != RPC_SUCCESS) {
 		return ret;
 	}
+	if((ret = RPC_CondAttrInit(&(rep->condAttr))) != RPC_SUCCESS) {
+		(void)RPC_MutexDestroy(&(rep->mutexId));
+		return ret;
+	}
+	if((ret = RPC_CondAttrSetPshared(&(rep->condAttr),IpcFlag?PTHREAD_PROCESS_SHARED:PTHREAD_PROCESS_PRIVATE)) != RPC_SUCCESS) {
+		(void)RPC_MutexDestroy(&(rep->mutexId));
+		return ret;
+	}
+	if((ret = RPC_InitCond(&(rep->condId),&(rep->condAttr))) != RPC_SUCCESS) {
+		(void)RPC_MutexDestroy(&(rep->mutexId));
+		return ret;
+	}
 	return RPC_SUCCESS;
 }
 
 static void IPC_destroyMutexForRendezv(IpcRendezvEntry_t *rep) {
+	(void)RPC_CondDestroy(&(rep->condId));
 	(void)RPC_MutexDestroy(&(rep->mutexId));
 }
 
@@ -1537,7 +1723,7 @@ static RpcTaskID_t senderTask,receiverTask;
 RpcResult_t RendezvTest(RpcBool_t IpcFlag) {
 //	RpcTaskID_t senderTask,receiverTask;
 	RpcTaskAttribute_t senderAttr,receiverAttr;
-	static uint32_t rendezvId;void *retVal;RpcResult_t ret;
+	static uint32_t rendezvId;void *retVal;RpcResult_t ret;uint32_t errCode;
 #if	0
 	struct timeval curTime;
 	uint32_t rend2, rend3,rend4,rend5,rend6,rend7;
@@ -1617,7 +1803,7 @@ RpcResult_t RendezvTest(RpcBool_t IpcFlag) {
 
 static void *rendezvSender(void* rendP) {
 	uint32_t rendezvId;static char *sendData="abcdefghijklmn";uint32_t sendSize;
-	char *replyData;uint32_t replySize;uint32_t timeOut;RpcResult_t ret;uint32_t errCode;
+	char *replyData;uint32_t replySize;uint32_t timeOut;RpcResult_t ret;
 	struct timeval sleepTime;uint32_t myPid;
 
 	rendezvId = (uint32_t)(*((uint32_t*)rendP));
@@ -1626,7 +1812,7 @@ static void *rendezvSender(void* rendP) {
 	(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_DEBUG1,"SEND DATA:%s; SIZE:%d;",sendData,sendSize);
 	sleepTime.tv_sec = 2;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	timeOut = 10*1000;
 	myPid = RPC_GetPid();
 
@@ -1661,7 +1847,7 @@ static void *rendezvSender(void* rendP) {
 
 static void *rendezvReceiver(void* rendP) {
 	uint32_t rendezvId;static char *replyData = "opqrstuvwxyz";uint32_t replySize;
-	char *recvData;uint32_t recvSize;uint32_t timeOut;RpcResult_t ret;uint32_t errCode;
+	char *recvData;uint32_t recvSize;uint32_t timeOut;RpcResult_t ret;
 	struct timeval sleepTime;uint32_t myPid;
 
 	rendezvId = (uint32_t)(*((uint32_t*)rendP));
@@ -1670,7 +1856,7 @@ static void *rendezvReceiver(void* rendP) {
 	(void)RPC_LogPrint(RPC_LOG_MODULE_RENDEZV,RPC_LOG_LEVEL_DEBUG1,"REPLY DATA:%s; SIZE:%d;",replyData,replySize);
 	sleepTime.tv_sec = 1;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	timeOut = 10*1000;
 	myPid = RPC_GetPid();
 
