@@ -128,7 +128,7 @@ static void IPC_printFreeAreaList(int fd);
 
 /* ----- SHM APIs - Global Functions ----- */
 
-RpcResult_t IPC_InitSharedMem(RpcBool_t masterProcess) {
+extern RpcResult_t IPC_InitSharedMem(RpcBool_t masterProcess) {
 	static RpcBool_t fInitFlag = RPC_FALSE;int i;uint32_t errCode;
 	struct stat statBuff;
 
@@ -199,7 +199,7 @@ RpcResult_t IPC_InitSharedMem(RpcBool_t masterProcess) {
 	return RPC_SUCCESS;
 }
 
-RpcResult_t IPC_DestroySharedMem(void) {
+extern RpcResult_t IPC_DestroySharedMem(void) {
 	int i;uint32_t errCode;
 
 	for(i = 0;i < IPC_SHARED_MEM_NUM;i++) {
@@ -215,7 +215,7 @@ RpcResult_t IPC_DestroySharedMem(void) {
 	return RPC_SUCCESS;
 }
 
-RpcResult_t IPC_AttachSharedMem(void) {
+extern RpcResult_t IPC_AttachSharedMem(void) {
 	int i;uint32_t errCode;void *retAddr;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"IN IPC_AttachSharedMem PID:0x%x;",RPC_GetPid());
@@ -240,7 +240,7 @@ RpcResult_t IPC_AttachSharedMem(void) {
 	return RPC_SUCCESS;
 }
 
-RpcResult_t IPC_DettachSharedMem(void) {
+extern RpcResult_t IPC_DettachSharedMem(void) {
 	int i;uint32_t errCode;
 
 	for(i = 0;i < IPC_SHARED_MEM_NUM;i++) {
@@ -253,7 +253,7 @@ RpcResult_t IPC_DettachSharedMem(void) {
 	return RPC_SUCCESS;
 }
 
-RpcResult_t IPC_GetShmInfo(char *name, int32_t *fd, void **addr, uint32_t *size) {
+extern RpcResult_t IPC_GetShmInfo(char *name, int32_t *fd, void **addr, uint32_t *size) {
 	int i;
 
 	for(i = 0;i < IPC_SHARED_MEM_NUM;i++) {
@@ -276,7 +276,7 @@ RpcResult_t IPC_GetShmInfo(char *name, int32_t *fd, void **addr, uint32_t *size)
 	return RPC_PARAM_ERROR;
 }
 
-RpcResult_t IPC_InitShmGapArea(int fd, uint32_t gapSize) {
+extern RpcResult_t IPC_InitShmGapArea(int fd, uint32_t gapSize) {
 	IpcShmManageArea_t *ap;void *mp;void *addr;uint32_t size;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"IN IPC_InitShmGapArea PID:0x%x; FD:0x%x; gapSize:%d;",
@@ -295,7 +295,7 @@ RpcResult_t IPC_InitShmGapArea(int fd, uint32_t gapSize) {
 	return RPC_SUCCESS;
 }
 
-RpcResult_t IPC_GetShmGapData(int fd,void **startArea, uint32_t *gapSize) {
+extern RpcResult_t IPC_GetShmGapData(int fd,void **startArea, uint32_t *gapSize) {
 	void *addr;uint32_t totalSize;IpcShmManageArea_t *ap;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"IN IPC_GetShmGapData PID:0x%x; FD:0x%x;",
@@ -311,7 +311,7 @@ RpcResult_t IPC_GetShmGapData(int fd,void **startArea, uint32_t *gapSize) {
 	return RPC_SUCCESS;
 }
 
-RpcResult_t IPC_InitShmAllocArea(int fd, uint32_t memSize, uint32_t numOfDev, uint32_t minSize, uint32_t rateOfMagnify) {
+extern RpcResult_t IPC_InitShmAllocArea(int fd, uint32_t memSize, uint32_t numOfDev, uint32_t minSize, uint32_t rateOfMagnify) {
 	void *addr;uint32_t size;IpcAreaInfo_t *areaInfo;IpcAreaManageInfo_t *manageInfo;
 	void *topAddr;uint32_t blockSize;uint32_t blockNum;uint32_t bSize;
 	int i;IpcShmManageArea_t *ap;
@@ -408,7 +408,7 @@ fatalError:
 	return RPC_FATAL_ERROR;
 }
 
-void *IPC_AllocShmMem(int fd, uint32_t size) {
+extern void *IPC_AllocShmMem(int fd, uint32_t size) {
 	void *addr;uint32_t totalSize;IpcAreaInfo_t *areaInfo;IpcAreaManageInfo_t *manageInfo;
 	int i;void *retAddr;IpcFixedAreaFreeInfo_t *fixedInfo;
 	IpcFreeAreaFreeInfo_t *freeInfo,*preFreeInfo,*newFreeInfo;
@@ -526,7 +526,7 @@ void *IPC_AllocShmMem(int fd, uint32_t size) {
 	return (void*)NULL;
 }
 
-void IPC_FreeShmMem(int fd, void *addr) {
+extern void IPC_FreeShmMem(int fd, void *addr) {
 	void *topAddr;uint32_t totalSize;IpcAreaInfo_t *areaInfo;IpcAreaManageInfo_t *manageInfo;
 	int i;IpcFixedAreaFreeInfo_t *fixedInfo,*preFixedInfo;
 	IpcFreeAreaFreeInfo_t *freeInfo,*preFreeInfo;
@@ -661,7 +661,7 @@ void IPC_FreeShmMem(int fd, void *addr) {
 	return;
 }
 
-uint32_t IPC_AllocatedSizeShmMem(int fd, void *addr) {
+extern uint32_t IPC_AllocatedSizeShmMem(int fd, void *addr) {
 	void *topAddr;uint32_t totalSize;IpcAreaInfo_t *areaInfo;IpcAreaManageInfo_t *manageInfo;
 	int i;IpcFixedAreaFreeInfo_t *fixedInfo;IpcFreeAreaUsedInfo_t *usedInfo;
 	uint32_t size = 0;IpcShmManageArea_t *ap;
@@ -712,7 +712,7 @@ uint32_t IPC_AllocatedSizeShmMem(int fd, void *addr) {
 	return 0;
 }
 
-void *IPC_ReallocShmMem(int fd, void *addr, uint32_t newSize) {
+extern void *IPC_ReallocShmMem(int fd, void *addr, uint32_t newSize) {
 	void *retAddr;uint32_t size;
 
 	if((retAddr = IPC_AllocShmMem(fd,newSize)) != (void*)NULL) {
@@ -728,12 +728,12 @@ void *IPC_ReallocShmMem(int fd, void *addr, uint32_t newSize) {
 }
 
 #if	0
-void *IPC_AllcShmMemWithTimeout(int fd, uint32_t size, uint32_t timeout) {
+extern void *IPC_AllcShmMemWithTimeout(int fd, uint32_t size, uint32_t timeout) {
 
 }
 
 
-void *IPC_ReallocShmMemWithTimeout(int fd, void *addr, uint32_t newSize, uint32_t timeout) {
+extern void *IPC_ReallocShmMemWithTimeout(int fd, void *addr, uint32_t newSize, uint32_t timeout) {
 
 }
 #endif	/* 0 */
