@@ -121,7 +121,7 @@ static void IPC_dumpDB(void);
 
 /* ----- DB APIs - Global Functions ----- */
 
-RpcResult_t IPC_InitShmDB(RpcBool_t masterProcess) {
+extern RpcResult_t IPC_InitShmDB(RpcBool_t masterProcess) {
 	void *startArea;uint32_t gapSize;
 	uint32_t fd; void *addr; uint32_t size;RpcResult_t ret;
 
@@ -214,7 +214,7 @@ goError:
 }
 
 //RpcResult_t IPC_RegisterFuncDBEntry(uint32_t funcId, uint32_t processId, uint16_t accessDevice, uint16_t accessProcess, IPC_SkeltonFunc_t func,IPC_SkeltonCancelFunc_t cancelFunc) {
-RpcResult_t IPC_RegisterFuncDBEntry(uint32_t funcId, uint32_t processId, IPC_SkeltonFunc_t func,IPC_SkeltonCancelFunc_t cancelFunc) {
+extern RpcResult_t IPC_RegisterFuncDBEntry(uint32_t funcId, uint32_t processId, IPC_SkeltonFunc_t func,IPC_SkeltonCancelFunc_t cancelFunc) {
 	IpcFuncDBEntry_t *entry;RpcResult_t ret;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"IN IPC_RegisterFuncDBEntry funcId:0x%x; processId:0x%x; func:0x%x; cancelFunc:0x%x;",funcId,processId,func,cancelFunc);
@@ -256,7 +256,7 @@ RpcResult_t IPC_RegisterFuncDBEntry(uint32_t funcId, uint32_t processId, IPC_Ske
 	return RPC_SUCCESS;
 }
 
-RpcResult_t IPC_SerachProcessIdFromFuncDB(uint32_t funcId,uint32_t *processId) {
+extern RpcResult_t IPC_SerachProcessIdFromFuncDB(uint32_t funcId,uint32_t *processId) {
 	IpcFuncDBEntry_t *entry;RpcResult_t ret;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG2,"IN IPC_SerachProcessIdFromFuncDB PID:0x%x; funcId:0x%x;",RPC_GetPid(),funcId);
@@ -276,8 +276,8 @@ RpcResult_t IPC_SerachProcessIdFromFuncDB(uint32_t funcId,uint32_t *processId) {
 	return RPC_SUCCESS;
 }
 
-//RpcResult_t IPC_SearchFunctionFromFuncDB(uint32_t funcId,IPC_SkeltonFunc_t *func,IPC_SkeltonCancelFunc_t *cancelFunc,uint16_t *accessProcessType, uint16_t *accessDeviceType) {
-RpcResult_t IPC_SearchFunctionFromFuncDB(uint32_t funcId,IPC_SkeltonFunc_t *func,IPC_SkeltonCancelFunc_t *cancelFunc) {
+//extern RpcResult_t IPC_SearchFunctionFromFuncDB(uint32_t funcId,IPC_SkeltonFunc_t *func,IPC_SkeltonCancelFunc_t *cancelFunc,uint16_t *accessProcessType, uint16_t *accessDeviceType) {
+extern RpcResult_t IPC_SearchFunctionFromFuncDB(uint32_t funcId,IPC_SkeltonFunc_t *func,IPC_SkeltonCancelFunc_t *cancelFunc) {
 	IpcFuncDBEntry_t *entry;RpcResult_t ret;
 
 	if((IpcDatabaseSharedMemId == -1)||(IpcDBManage == (IpcDBManage_t*)NULL)) {
@@ -298,7 +298,7 @@ RpcResult_t IPC_SearchFunctionFromFuncDB(uint32_t funcId,IPC_SkeltonFunc_t *func
 	return RPC_SUCCESS;
 }
 
-RpcResult_t IPC_DeleteFuncDBEntry(uint32_t funcId) {
+extern RpcResult_t IPC_DeleteFuncDBEntry(uint32_t funcId) {
 	RpcResult_t ret;
 
 	if((IpcDatabaseSharedMemId == -1)||(IpcDBManage == (IpcDBManage_t*)NULL)) {
@@ -316,8 +316,8 @@ RpcResult_t IPC_DeleteFuncDBEntry(uint32_t funcId) {
 	return RPC_SUCCESS;
 }
 
-//RpcResult_t IPC_RegisterSkeltonDBEntry(uint32_t processId,uint32_t taskId, uint32_t queId,IpcProcessType_t processType) {
-RpcResult_t IPC_RegisterSkeltonDBEntry(uint32_t processId,uint32_t taskId, uint32_t queId) {
+//extern RpcResult_t IPC_RegisterSkeltonDBEntry(uint32_t processId,uint32_t taskId, uint32_t queId,IpcProcessType_t processType) {
+extern RpcResult_t IPC_RegisterSkeltonDBEntry(uint32_t processId,uint32_t taskId, uint32_t queId) {
 	IpcSkeltonDBEntry_t *entry;RpcResult_t ret;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM_DB, RPC_LOG_LEVEL_DEBUG1, "IN IPC_RegisterSkeltonDBEntry processId:0x%x; taskId:0x%x; queId:0x%x; ipcDBMange:0x%x;",
@@ -349,7 +349,7 @@ RpcResult_t IPC_RegisterSkeltonDBEntry(uint32_t processId,uint32_t taskId, uint3
 	return RPC_SUCCESS;
 }
 
-RpcResult_t IPC_SearchSkeltonDB(uint32_t processId, uint32_t *taskId,uint32_t *queId) {
+extern RpcResult_t IPC_SearchSkeltonDB(uint32_t processId, uint32_t *taskId,uint32_t *queId) {
 	IpcSkeltonDBEntry_t *entry;RpcResult_t ret;
 
 	if((IpcDatabaseSharedMemId == -1)||(IpcDBManage == (IpcDBManage_t*)NULL)) {
@@ -368,7 +368,7 @@ RpcResult_t IPC_SearchSkeltonDB(uint32_t processId, uint32_t *taskId,uint32_t *q
 	return RPC_SUCCESS;
 }
 
-RpcResult_t IPC_DeleteSkeltonDBEntry(uint32_t processId) {
+extern RpcResult_t IPC_DeleteSkeltonDBEntry(uint32_t processId) {
 	RpcResult_t ret;
 
 	if((IpcDatabaseSharedMemId == -1)||(IpcDBManage == (IpcDBManage_t*)NULL)) {
@@ -383,15 +383,15 @@ RpcResult_t IPC_DeleteSkeltonDBEntry(uint32_t processId) {
 }
 
 #if	0
-RpcResult_t IPC_registerProcessData(uint32_t processId,IpcProcessType_t processType) {
+extern RpcResult_t IPC_registerProcessData(uint32_t processId,IpcProcessType_t processType) {
 	return IPC_registerSkeltonDBEntry(processId,0,0,processType);
 }
 
-RpcResult_t IPC_delegateProcessData(uint32_t processId) {
+extern RpcResult_t IPC_delegateProcessData(uint32_t processId) {
 	return IPC_DeleteSkeltonDBEntry(processId);
 }
 
-RpcResult_t IPC_searchProcessType(uint32_t processId, IpcProcessType_t *processType) {
+extern RpcResult_t IPC_searchProcessType(uint32_t processId, IpcProcessType_t *processType) {
 	IpcSkeltonDBEntry_t *entry;RpcResult_t ret;
 
 	if((IpcDatabaseSharedMemId == -1)||(IpcDBManage == (IpcDBManage_t*)NULL)) {
@@ -412,39 +412,39 @@ RpcResult_t IPC_searchProcessType(uint32_t processId, IpcProcessType_t *processT
 
 #ifdef	USE_MULTICAST_RPC
 
-RpcResult_t IPC_RegisterMulticastFunc(uint32_t mltcstFuncId) {
+extern RpcResult_t IPC_RegisterMulticastFunc(uint32_t mltcstFuncId) {
 	uint32_t pid;
 
 	pid = RPC_GetPid();
 	return IPC_registerMulticastFunction(pid,mltcstFuncId);
 }
 
-RpcResult_t IPC_SignupMulticastFunc(uint32_t mltcstFuncId, uint32_t funcId) {
+extern RpcResult_t IPC_SignupMulticastFunc(uint32_t mltcstFuncId, uint32_t funcId) {
 	uint32_t pid;
 
 	pid = RPC_GetPid();
 	return IPC_registerFunctionInMulticastFunc(pid, mltcstFuncId, funcId);
 }
 
-RpcResult_t IPC_ResignMulticastFunc(uint32_t mltcstFuncId, uint32_t funcId) {
+extern RpcResult_t IPC_ResignMulticastFunc(uint32_t mltcstFuncId, uint32_t funcId) {
 	uint32_t pid;
 
 	pid = RPC_GetPid();
 	return IPC_unregisterFunctionInMulticastFunc(pid, mltcstFuncId, funcId);
 }
 
-RpcResult_t IPC_UnregisterMulticastFunc(uint32_t mltcstFuncId) {
+extern RpcResult_t IPC_UnregisterMulticastFunc(uint32_t mltcstFuncId) {
 	uint32_t pid;
 
 	pid = RPC_GetPid();
 	return IPC_unregisterMulticastFunction(pid, mltcstFuncId);
 }
 
-RpcResult_t IPC_GetFuncListByMltcstFuncId(uint32_t mltcstFuncId, RpcList_t **funcList) {
+extern RpcResult_t IPC_GetFuncListByMltcstFuncId(uint32_t mltcstFuncId, RpcList_t **funcList) {
 	return IPC_GetFuncListFromMulticastFunction(mltcstFuncId,funcList);
 }
 
-void IPC_FreeFuncList(RpcList_t *funcList) {
+extern void IPC_FreeFuncList(RpcList_t *funcList) {
 	while(funcList != (RpcList_t*)NULL) {
 		RPC_FreeListData(&funcList,(void*)(funcList->entry),0,RPC_LclFreeMemWrapper);
 	}
