@@ -228,7 +228,7 @@ static RpcResult_t IPC_initSkeltonResourceDB(void) {
 
 static void *IPC_skeltonManagerMain(void *arg1) {
 	uint32_t queId;uint32_t msgId;RpcMsgParam_t msgParam;RpcResult_t ret;
-	uint32_t newTaskId;uint32_t newQueId;uint32_t errCode;RpcMsgParam_t retMsgParam;
+	uint32_t newTaskId;uint32_t newQueId;RpcMsgParam_t retMsgParam;
 	uint32_t pid;
 	struct timeval sleepTime;
 
@@ -236,13 +236,12 @@ static void *IPC_skeltonManagerMain(void *arg1) {
 	(void)RPC_SetCancelType(PTHREAD_CANCEL_DEFERRED ,NULL);
 	queId = (uint32_t)(*(uint32_t*)arg1);
 	pid = (uint32_t)RPC_GetPid();
-	sleepTime.tv_sec = IPC_MSG_QUE_DEFAULT_TIMEOUT/1000;
-	sleepTime.tv_usec = (IPC_MSG_QUE_DEFAULT_TIMEOUT%1000)*1000;
+	RPC_ConvertTimeoutToTimeval(IPC_MSG_QUE_DEFAULT_TIMEOUT,&sleepTime);
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1, "IN IPC_skeltonManagerMain queId:0x%x; pid:0x%x;",queId,pid);
 	for(;;) {
 		if((ret = IPC_GetMsgFromExtQue(queId,&msgId,&msgParam,IPC_MSG_QUE_WAIT_FOREVER)) != RPC_SUCCESS) {
 			(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_FATAL, " ERROR in IPC_GetMsgFromExtQue in SkeltonManagerMain QUE-ID:%d; ret:%s",queId, RPC_LogConvertResultCode(ret));
-			(void)RPC_TaskSleep(&sleepTime,(struct timeval*)NULL,&errCode);
+			(void)RPC_TaskSleep(&sleepTime,(struct timeval*)NULL);
 			continue;
 		}
 //		(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG2,"  RECEIVE MSG IN SKELTON-MAIN PID:0x%x; QUEID:0x%x; ID:0x%x; funcId:0x%x; srcPid:0x%x; srcQueId:0x%x, seqNum:0x%x; extData:0x%x;",
@@ -295,10 +294,11 @@ static void *IPC_skeltonManagerMain(void *arg1) {
 }
 
 static void *IPC_skeltonTaskMain(void *arg1) {
-	uint32_t queId;uint32_t msgId;RpcMsgParam_t msgParam;RpcResult_t ret;uint32_t errCode;
+	uint32_t queId;uint32_t msgId;RpcMsgParam_t msgParam;RpcResult_t ret;
 	int32_t (*func)(uint32_t processId, uint32_t seqNum, void *inData ,uint32_t inSize, void **outData, int32_t *outSize, uint32_t timeOut);
 	int32_t (*cancelFunc)(uint32_t processId, uint32_t seqNum);
-	uint32_t pid;void *outData;int32_t outSize;int32_t funcRet;RpcParamHeader_t *header;
+	uint32_t pid;void *outData;int32_t outSize;int32_t funcRet;
+	uint32_t paramLength;
 	RpcMsgParam_t retMsgParam;RpcTaskID_t myTaskId;
 //	uint16_t accessProcessType;uint16_t accessDeviceType;
 	struct timeval sleepTime;
@@ -308,13 +308,12 @@ static void *IPC_skeltonTaskMain(void *arg1) {
 	pid = (uint32_t)RPC_GetPid();
 	queId = (uint32_t)(*(uint32_t*)arg1);
 	myTaskId = RPC_TaskSelf();
-	sleepTime.tv_sec = IPC_MSG_QUE_DEFAULT_TIMEOUT/1000;
-	sleepTime.tv_usec = (IPC_MSG_QUE_DEFAULT_TIMEOUT%1000)*1000;
+	RPC_ConvertTimeoutToTimeval(IPC_MSG_QUE_DEFAULT_TIMEOUT,&sleepTime);
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1, "IN IPC_skeltonTaskMain pid:0x%x; queId:0x%x; myTaskId:%d;",pid,queId,myTaskId);
 	for(;;) {
 		if((ret = IPC_GetMsgFromQue(queId,&msgId,&msgParam,IPC_MSG_QUE_WAIT_FOREVER)) != RPC_SUCCESS) {
 			(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_FATAL, " ERROR in IPC_GetMsgFromQue in SkeltonTaskMain QUE-ID:%d; ret:%s",queId, RPC_LogConvertResultCode(ret));
-			(void)RPC_TaskSleep(&sleepTime,(struct timeval*)NULL,&errCode);
+			(void)RPC_TaskSleep(&sleepTime,(struct timeval*)NULL);
 			continue;
 		}
 //		(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG2,"  RECEIVE MSG IN SKELTON-TASK PID:0x%x; QUEID:0x%x; ID:0x%x; funcId:0x%x; srcPid:0x%x; srcQueId:0x%x, seqNum:0x%x; extData:0x%x;",
@@ -354,9 +353,9 @@ static void *IPC_skeltonTaskMain(void *arg1) {
 				(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_SKELTON, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 				break;
 			}
-			header = (RpcParamHeader_t*)msgParam.u.msgParam.extParam;
+			paramLength = IPC_GetMarshaledDataSize((void*)(msgParam.u.msgParam.extParam));
 //			(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG2,"  EXEC FUNC PID:0x%x; FUNC:0x%x;", pid, func);
-			if((funcRet = func(msgParam.u.msgParam.srcPid, msgParam.u.msgParam.seqNum,msgParam.u.msgParam.extParam,header->paramLength, &outData,&outSize, msgParam.u.msgParam.extData)) != RPC_SUCCESS) {
+			if((funcRet = func(msgParam.u.msgParam.srcPid, msgParam.u.msgParam.seqNum,msgParam.u.msgParam.extParam,paramLength, &outData,&outSize, msgParam.u.msgParam.extData)) != RPC_SUCCESS) {
 				(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON, RPC_LOG_LEVEL_WARNING, "FAIL TO EXEC FUNCTION ID:0x%x; RET:%s; ERR-CODE:%s;",msgParam.u.msgParam.funcId,RPC_LogConvertResultCode(ret));
 			}
 //			(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG2,"  RETURN FUNC PID:0x%x; FUNC:0x%x;", pid, func);
