@@ -1203,7 +1203,7 @@ static RpcBool_t IPC_compareQueResourceByState(RpcList_t *list,uint32_t state) {
 }
 
 static RpcResult_t IPC_allocStubCBTaskResource(IpcStubCBTaskResourceDBEntry_t *entry) {
-	RpcResult_t ret;
+	RpcResult_t ret;RpcTaskSchedParam_t schedParam;
 
 	if((ret = RPC_CreateTaskControl(RPC_FALSE,&(entry->tskCntl))) != RPC_SUCCESS) {
 		return ret;
@@ -1220,6 +1220,11 @@ static RpcResult_t IPC_allocStubCBTaskResource(IpcStubCBTaskResourceDBEntry_t *e
 		(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_FATAL, " CAN NOT SET SCHED POLICY ret:%s",RPC_LogConvertResultCode(ret));
 		goto errOut;
 	}
+	schedParam.sched_priority = (int)IPC_STUB_CB_TASK_PRIORITY;
+	if((ret = RPC_TaskAttrSetSchedParam(&(entry->taskAttr),&schedParam)) != RPC_SUCCESS) {
+		(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_FATAL, " CAN NOT SET SCHED POLICY ret:%s",RPC_LogConvertResultCode(ret));
+		goto errOut;
+	}	
 	if((ret = RPC_TaskAttrSetStackSize(&(entry->taskAttr), IPC_STUB_CB_TASK_STACK_SIZE)) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_FATAL, " CAN NOT SET STACK SIZE ret:%s",RPC_LogConvertResultCode(ret));
 		goto errOut;
