@@ -316,20 +316,20 @@ extern RpcResult_t RPC_TaskYield(void) {
 #endif	/* __USE_GNU */
 }
 
-extern RpcResult_t RPC_TaskSleep(struct timeval *sleepTime,struct timeval *remainTime,uint32_t *errCode) {
+extern RpcResult_t RPC_TaskSleep(struct timeval *sleepTime,struct timeval *remainTime) {
 	struct timespec req,rem;
+//	uint32_t errCode;
 
 	if(remainTime != (struct timeval*)NULL) {
 		(void)memset((void*)remainTime,0,sizeof(struct timeval));
 	}
 	if(sleepTime == (struct timeval*)NULL) {
-		*errCode = RPC_ERR_OTHER;
 		return RPC_PARAM_ERROR;
 	}
 	req.tv_sec = sleepTime->tv_sec;
 	req.tv_nsec = sleepTime->tv_usec * 1000;
 	if(nanosleep(&req,&rem) != 0) {
-		RPC_convertErrno(errno,errCode);
+//		RPC_convertErrno(errno,&errCode);
 		if(remainTime != (struct timeval*)NULL) {
 			remainTime->tv_sec = rem.tv_sec;
 			remainTime->tv_usec = rem.tv_nsec * 1000;
@@ -344,7 +344,6 @@ extern RpcResult_t RPC_TaskSleep(struct timeval *sleepTime,struct timeval *remai
 		(void)memset((void*)remainTime,0,sizeof(struct timeval));
 #endif	/* 0 */
 	}
-	*errCode = RPC_NO_ERROR;
 	return RPC_SUCCESS;
 }
 
