@@ -58,22 +58,23 @@
 
 #include	"ipcType.h"
 
-typedef pthread_t						RpcTaskID_t;
-typedef pthread_attr_t						RpcTaskAttribute_t;
-typedef struct sched_param					RpcTaskSchedParam_t;
-typedef pthread_mutex_t						RpcMutexID_t;
-typedef pthread_mutexattr_t					RpcMutexAttribute_t;
-typedef pthread_cond_t						RpcCondID_t;
-typedef pthread_condattr_t					RpcCondAttribute_t;
-typedef sem_t							RpcSem_t;
+typedef pthread_t					RpcTaskID_t;
+typedef pthread_attr_t					RpcTaskAttribute_t;
+typedef struct sched_param				RpcTaskSchedParam_t;
+typedef pthread_mutex_t					RpcMutexID_t;
+typedef pthread_mutexattr_t				RpcMutexAttribute_t;
+typedef pthread_cond_t					RpcCondID_t;
+typedef pthread_condattr_t				RpcCondAttribute_t;
+typedef sem_t						RpcSem_t;
 
 typedef enum {
 	RPC_SCHED_PRIO_UNKNOWN = 0,
-	RPC_SCHED_PRIO_IDLE = 1,
-	RPC_SCHED_PRIO_OTHER = 2,
+	RPC_SCHED_PRIO_IDLE = 0,
+	RPC_SCHED_PRIO_BATCH = 0,
+	RPC_SCHED_PRIO_OTHER = 0,
 	RPC_SCHED_PRIO_LOW_L = 10,
 	RPC_SCHED_PRIO_LOW_M = 20,
-	RPC_SCHED_PRIO_LOW_H= 30,
+	RPC_SCHED_PRIO_LOW_H = 30,
 	RPC_SCHED_PRIO_MID_L = 40,
 	RPC_SCHED_PRIO_MID_M = 50,
 	RPC_SCHED_PRIO_MID_H = 60,
@@ -100,10 +101,10 @@ extern RpcTaskID_t RPC_TaskSelf(void);
 //extern RpcResult_t RPC_TaskPushClenaupDeferNP(void (*routine)(void*), void *arg);
 //extern RpcResult_t RPC_TaskPopCleanupRestoreNP(int execute);
 
-#define	RPC_TaskPushCleanup(routine,arg)			pthread_cleanup_push(routine,arg)
-#define	RPC_TaskPopCleanup(execute)				pthread_cleanup_pop(execute)
-#define	RPC_TaskPushClenaupDeferNP(routine,arg)			pthread_cleanup_push_defer_np(routine, arg)
-#define	RPC_TaskPopCleanupRestoreNP(execute)			pthread_cleanup_pop_defer_np(execute)
+#define	RPC_TaskPushCleanup(routine,arg)		pthread_cleanup_push(routine,arg)
+#define	RPC_TaskPopCleanup(execute)			pthread_cleanup_pop(execute)
+#define	RPC_TaskPushClenaupDeferNP(routine,arg)		pthread_cleanup_push_defer_np(routine, arg)
+#define	RPC_TaskPopCleanupRestoreNP(execute)		pthread_cleanup_pop_defer_np(execute)
 
 extern RpcResult_t RPC_TaskAttrInit(RpcTaskAttribute_t *taskAttr);
 extern RpcResult_t RPC_TaskAttrSetDetachState(RpcTaskAttribute_t *taskAttr, int detachState);
@@ -121,7 +122,7 @@ extern RpcResult_t RPC_TaskAttrSetStack(RpcTaskAttribute_t *taskAttr, void *stac
 extern RpcResult_t RPC_TaskAttrGetStack(RpcTaskAttribute_t *taskAttr, void **stackAddr, int *stackSize);
 
 extern RpcResult_t RPC_TaskYield(void);
-extern RpcResult_t RPC_TaskSleep(struct timeval *sleepTime,struct timeval *remainTime,uint32_t *errCode);
+extern RpcResult_t RPC_TaskSleep(struct timeval *sleepTime,struct timeval *remainTime);
 
 extern RpcResult_t RPC_InitMutex(RpcMutexID_t *mutexID, RpcMutexAttribute_t *mutexAttr);
 extern RpcResult_t RPC_MutexLock(RpcMutexID_t *mutexID);
@@ -185,17 +186,17 @@ extern RpcResult_t RPC_WaitPid(int32_t *pid,int *status,int options,uint32_t *er
 extern void RPC_Exit(int32_t status);
 extern RpcResult_t RPC_Kill(int32_t pid,int32_t sig,uint32_t *errCode);
 
-#define	RPC_WNOHANG						WNOHANG
-#define	RPC_WUNTRACED						WUNTRACED
-#define	RPC_WCONTINUED						WCONTINUED
+#define	RPC_WNOHANG					WNOHANG
+#define	RPC_WUNTRACED					WUNTRACED
+#define	RPC_WCONTINUED					WCONTINUED
 
-#define	RPC_WIFEXITED(status)					WIFEXITED(status)
-#define	RPC_WEXITSTATUS(status)					WEXITSTATUS(status)
-#define	RPC_WIFSIGNALED(status)					WIFSIGNALED(status)
-#define	RPC_WTERMSIG(status)					WTERMSIG(status)
-#define	RPC_WCOREDUMP(status)					WCOREDUMP(status)
-#define	RPC_WIFSTOPPED(status)					WIFSTOPPED(status)
-#define	RPC_WSTOPSIG(status)					WSTIPSIG(status)
-#define	RPC_WIFCONTINUED(status)				WIFCONTINUED(status)
+#define	RPC_WIFEXITED(status)				WIFEXITED(status)
+#define	RPC_WEXITSTATUS(status)				WEXITSTATUS(status)
+#define	RPC_WIFSIGNALED(status)				WIFSIGNALED(status)
+#define	RPC_WTERMSIG(status)				WTERMSIG(status)
+#define	RPC_WCOREDUMP(status)				WCOREDUMP(status)
+#define	RPC_WIFSTOPPED(status)				WIFSTOPPED(status)
+#define	RPC_WSTOPSIG(status)				WSTIPSIG(status)
+#define	RPC_WIFCONTINUED(status)			WIFCONTINUED(status)
 
 #endif /* IPCSYSCALL_H_ */
