@@ -50,8 +50,8 @@
 
 #include	"ipcTest.h"
 
-#define	MULTICAST_TEST
-//#undef	MULTICAST_TEST
+//#define	MULTICAST_TEST
+#undef	MULTICAST_TEST
 
 RpcResult_t queTest(RpcBool_t globalFlag);
 RpcResult_t shmTest(void);
@@ -188,7 +188,7 @@ int main(int argc,char *argv[]) {
 		{
 		sleepTime.tv_sec = 0;
 		sleepTime.tv_usec = 100*1000;
-		(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+		(void)RPC_TaskSleep(&sleepTime,NULL);
 		RPC_LogPrint(RPC_LOG_MODULE_MAIN,RPC_LOG_LEVEL_DEBUG1,"NOW REGISTER AND SIGNUP MULTICAST FUNCTION");
 		if(IPC_RegisterMulticastFunc(IPC_FUNC_ID_MLTCST_TST_1) != RPC_SUCCESS) {
 			RPC_LogPrint(RPC_LOG_MODULE_MAIN,RPC_LOG_LEVEL_ERROR,"ERROR CAN NOT REGISTER MULTICAST FUNCTION ID:0x%x;",IPC_FUNC_ID_MLTCST_TST_1);
@@ -210,7 +210,7 @@ int main(int argc,char *argv[]) {
 	else {int32_t pid,skelPid;RpcResult_t (*skelFunction)(void);RpcResult_t (*skelCancel)(void);
 		sleepTime.tv_sec = 0;
 		sleepTime.tv_usec = 100*1000;
-		(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+		(void)RPC_TaskSleep(&sleepTime,NULL);
 		pid = RPC_GetPid();
 		for(i = 0;i < NUM_OF_TEST_PROGRAM;i++ ) {
 			if(IPC_SerachProcessIdFromFuncDB(skelFuncID[i],&skelPid) == RPC_SUCCESS) {
@@ -257,11 +257,11 @@ static RpcResult_t FunctionC(uint32_t count, char *fromProcess, char *toProcess,
 static RpcResult_t setSkeltonParam(uint32_t retVal, char *fromRet, char *toRet, RpcParamData_t *retParam, void **outData, int32_t *outSize);
 
 RpcResult_t SkeltonTest1(void) {
-	struct timeval sleepTime;uint32_t errCode;RpcResult_t ret;uint32_t pid;
+	struct timeval sleepTime;RpcResult_t ret;uint32_t pid;
 #ifdef	MULTICAST_TEST
 	sleepTime.tv_sec = 1;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 #endif	/* MULTICAST_TEST */
 	pid = RPC_GetPid();
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"IN SkeltonTest1 PID:0x%x;",pid);
@@ -275,18 +275,18 @@ RpcResult_t SkeltonTest1(void) {
 #endif	/* USE_MULTICAST_RPC */
 	sleepTime.tv_sec = 10;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"OUT SkeltonTest1 PID:0x%x;",RPC_GetPid());	
 	return RPC_SUCCESS;
 }
 
 RpcResult_t SkeltonTest2(void) {
-	struct timeval sleepTime;uint32_t errCode;RpcResult_t ret;uint32_t pid;
+	struct timeval sleepTime;RpcResult_t ret;uint32_t pid;
 
 #ifdef	MULTICAST_TEST
 	sleepTime.tv_sec = 1;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 #endif	/* MULTICAST_TEST */
 	pid = RPC_GetPid();
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"IN SkeltonTest2 PID:0x%x;",pid);
@@ -300,19 +300,19 @@ RpcResult_t SkeltonTest2(void) {
 #endif	/* USE_MULTICAST_RPC */
 	sleepTime.tv_sec = 10;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"OUT SkeltonTest2 PID:0x%x;",RPC_GetPid());	
 	return RPC_SUCCESS;
 }
 
 RpcResult_t SkeltonTest3(void) {
-	struct timeval sleepTime;uint32_t errCode;RpcResult_t ret;uint32_t pid;
+	struct timeval sleepTime;RpcResult_t ret;uint32_t pid;
 
 #ifdef	MULTICAST_TEST
 	sleepTime.tv_sec = 1;
 	sleepTime.tv_usec = 0;
 #endif	/* MULTICAST_TEST */
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	pid = RPC_GetPid();
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"IN SkeltonTest3 PID:0x%x;",pid);
 	if((ret = IPC_RegisterFuncDBEntry(IPC_FUNCTION_C_FUNC_ID, pid, skeltonFuncC,skeltonFuncCancelC)) != RPC_SUCCESS) {
@@ -325,7 +325,7 @@ RpcResult_t SkeltonTest3(void) {
 #endif	/* USE_MULTICAST_RPC */
 	sleepTime.tv_sec = 10;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"OUT SkeltonTest3 PID:0x%x;",RPC_GetPid());	
 	return RPC_SUCCESS;
 }
@@ -372,12 +372,12 @@ static RpcResult_t skeltonFuncA(uint32_t processId, uint32_t seqNum, void *inDat
 }
 
 static RpcResult_t skeltonFuncCancelA(uint32_t processId, uint32_t seqNum) {
-	struct timeval sleepTime;uint32_t errCode;
+	struct timeval sleepTime;;
 
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"IN skeltonFuncCancelA PID:0x%x; seqNum:0x%x;",processId, seqNum);
 	sleepTime.tv_sec = 3;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"OUT skeltonFuncCancelA PID:0x%x; seqNum:0x%x;",processId, seqNum);
 	return RPC_SUCCESS;
 }
@@ -425,12 +425,12 @@ static RpcResult_t skeltonFuncB(uint32_t processId, uint32_t seqNum, void *inDat
 }
 
 static RpcResult_t skeltonFuncCancelB(uint32_t processId, uint32_t seqNum) {
-	struct timeval sleepTime;uint32_t errCode;
+	struct timeval sleepTime;
 
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"IN skeltonFuncCancelB PID:0x%x; seqNum:0x%x;",processId, seqNum);
 	sleepTime.tv_sec = 3;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"OUT skeltonFuncCancelB PID:0x%x; seqNum:0x%x;",processId, seqNum);
 	return RPC_SUCCESS;
 }
@@ -477,26 +477,26 @@ static RpcResult_t skeltonFuncC(uint32_t processId, uint32_t seqNum, void *inDat
 }
 
 static RpcResult_t skeltonFuncCancelC(uint32_t processId, uint32_t seqNum) {
-	struct timeval sleepTime;uint32_t errCode;
+	struct timeval sleepTime;
 
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"IN skeltonFuncCancelC PID:0x%x; seqNum:0x%x;",processId, seqNum);
 	sleepTime.tv_sec = 3;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"OUT skeltonFuncCancelC PID:0x%x; seqNum:0x%x;",processId, seqNum);
 	return RPC_SUCCESS;
 }
 
 static RpcResult_t FunctionA(uint32_t count, char *fromProcess, char *toProcess, uint32_t *retVal, char *fromRet, char *toRet) {
 	RpcResult_t ret = RPC_SUCCESS;char newFrom[1024]; char newTo[1024];
-	struct timeval sleepTime;uint32_t errCode;
+	struct timeval sleepTime;
 
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"IN FunctionA PID:0x%x; count:%d; fromProcess:%s; toProcess:%s;",RPC_GetPid(),count, fromProcess, toProcess);
 	count--;
 	if(count > 0) {
 		sleepTime.tv_sec = 1;
 		sleepTime.tv_usec = 0;
-		(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+		(void)RPC_TaskSleep(&sleepTime,NULL);
 
 		strcpy(newFrom,"SkeltonTest1");
 		strcpy(newTo,"SkeltonTest2");
@@ -513,7 +513,7 @@ static RpcResult_t FunctionA(uint32_t count, char *fromProcess, char *toProcess,
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1," ##### OK COUNT IS 0, SO FINISH IN FunctionA PID:0x%x; #####",RPC_GetPid());
 		sleepTime.tv_sec = 2;
 		sleepTime.tv_usec = 0;
-		(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+		(void)RPC_TaskSleep(&sleepTime,NULL);
 	}
 	*retVal = 0xA;
 	strcpy(fromRet,"SkeltonTest1");
@@ -524,14 +524,14 @@ static RpcResult_t FunctionA(uint32_t count, char *fromProcess, char *toProcess,
 
 static RpcResult_t FunctionB(uint32_t count, char *fromProcess, char *toProcess, uint32_t *retVal, char *fromRet, char *toRet) {
 	RpcResult_t ret = RPC_SUCCESS;char newFrom[1024]; char newTo[1024];
-	struct timeval sleepTime;uint32_t errCode;
+	struct timeval sleepTime;
 
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"IN FunctionB PID:0x%x; count:%d; fromProcess:%s; toProcess:%s;",RPC_GetPid(),count, fromProcess, toProcess);
 	count--;
 	if(count > 0) {
 		sleepTime.tv_sec = 1;
 		sleepTime.tv_usec = 0;
-		(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+		(void)RPC_TaskSleep(&sleepTime,NULL);
 
 		strcpy(newFrom,"SkeltonTest2");
 		strcpy(newTo,"SkeltonTest3");
@@ -548,7 +548,7 @@ static RpcResult_t FunctionB(uint32_t count, char *fromProcess, char *toProcess,
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1," ##### OK COUNT IS 0, SO FINISH IN FunctionB PID:0x%x; #####",RPC_GetPid());
 		sleepTime.tv_sec = 2;
 		sleepTime.tv_usec = 0;
-		(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+		(void)RPC_TaskSleep(&sleepTime,NULL);
 	}
 	*retVal = 0xB;
 	strcpy(fromRet,"SkeltonTest2");
@@ -559,14 +559,14 @@ static RpcResult_t FunctionB(uint32_t count, char *fromProcess, char *toProcess,
 
 static RpcResult_t FunctionC(uint32_t count, char *fromProcess, char *toProcess, uint32_t *retVal, char *fromRet, char *toRet) {
 	RpcResult_t ret = RPC_SUCCESS;char newFrom[1024]; char newTo[1024];
-	struct timeval sleepTime;uint32_t errCode;
+	struct timeval sleepTime;
 
 	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1,"IN FunctionC PID:0x%x; count:%d; fromProcess:%s; toProcess:%s;",RPC_GetPid(),count, fromProcess, toProcess);
 	count--;
 	if(count > 0) {
 		sleepTime.tv_sec = 1;
 		sleepTime.tv_usec = 0;
-		(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+		(void)RPC_TaskSleep(&sleepTime,NULL);
 
 		strcpy(newFrom,"SkeltonTest3");
 		strcpy(newTo,"SkeltonTest1");
@@ -583,7 +583,7 @@ static RpcResult_t FunctionC(uint32_t count, char *fromProcess, char *toProcess,
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1," ##### OK COUNT IS 0, SO FINISH IN FunctionC PID:0x%x; #####",RPC_GetPid());
 		sleepTime.tv_sec = 2;
 		sleepTime.tv_usec = 0;
-		(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+		(void)RPC_TaskSleep(&sleepTime,NULL);
 	}
 	*retVal = 0xC;
 	strcpy(fromRet,"SkeltonTest3");
@@ -593,7 +593,7 @@ static RpcResult_t FunctionC(uint32_t count, char *fromProcess, char *toProcess,
 }
 
 static RpcResult_t setSkeltonParam(uint32_t retVal, char *fromRet, char *toRet, RpcParamData_t *retParam, void **outData, int32_t *outSize) {
-	RpcResult_t ret;uint32_t errCode;
+	RpcResult_t ret;
 
 	retParam[0].paramSpec.paramType = RPC_UINT_TYPE;
 	retParam[0].paramSpec.paramLeng = 4;
@@ -637,7 +637,7 @@ RpcResult_t StubTestA(void) {
 	sleepTime.tv_sec = 1;
 #endif	/* MULTICAST_TEST */
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 #ifdef	MULTICAST_TEST
 	count = 2;
 #else	/* MULTICAST_TEST */
@@ -660,7 +660,7 @@ RpcResult_t StubTestA(void) {
 	(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_DEBUG1," OK CREATE A TASK ID:0x%x;",taskId);
 	sleepTime.tv_sec = 3;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_DEBUG1," OK NOW CANCEL TASK ID:0x%x;",taskId);
 	ret = RPC_StubSyncCancel(taskId,&errCode);
 	(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_DEBUG1," RETURN FROM THE CANCEL TASKID:0x%x; RET:%d; errCode:%s;",
@@ -679,11 +679,11 @@ RpcResult_t StubTestA(void) {
 #if	1
 	sleepTime.tv_sec = 8;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 #else	/* 0 */	/* CANCEL TEST FOR ASYNC CALL */
 	sleepTime.tv_sec = 1;
 	sleepTime.tv_usec = 0;	/* 300msec */
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	if((ret = RPC_StbuAsyncCancel(seqNum,&errCode)) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_ERROR,"ERROR IN RPC_StbuAsyncCancel RET-CODE:%s; ERR-CODE:%s;",
 			RPC_LogConvertResultCode(ret),RPC_LogConvertErrCode(errCode));
@@ -692,14 +692,14 @@ RpcResult_t StubTestA(void) {
 	}
 	sleepTime.tv_sec = 8;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 #endif	/* 0 */
 	(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_DEBUG1,"OUT StubTestA PID:0x%x;",RPC_GetPid());	
 	return RPC_SUCCESS;
 }
 
 static void *StubSyncTestA(void *arg) {
-	struct timeval sleepTime;uint32_t errCode;RpcResult_t ret;uint32_t pid;
+	struct timeval sleepTime;RpcResult_t ret;uint32_t pid;
 	uint32_t count;uint32_t seqNum;
 	char *fromProcess;char *toProcess;
 	uint32_t retVal;char fromRet[1024]; char toRet[1024];
@@ -708,7 +708,7 @@ static void *StubSyncTestA(void *arg) {
 	(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_DEBUG1,"IN StubSyncTestA PID:0x%x; TASKID:0x%x;",pid,RPC_TaskSelf());
 	sleepTime.tv_sec = 1;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	count = 6;
 	fromProcess = "StubSyncTestA";
 	toProcess = "SkeltonTest2";
@@ -720,7 +720,7 @@ static void *StubSyncTestA(void *arg) {
 	(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_DEBUG1," ##### OK SUCCESS TO RETURN SYNC FUNC RET-VAL:0x%x; fromRet:%s; toRet:%s; #####",retVal, fromRet, toRet);
 	sleepTime.tv_sec = 2;
 	sleepTime.tv_usec = 0;
-	(void)RPC_TaskSleep(&sleepTime,NULL,&errCode);
+	(void)RPC_TaskSleep(&sleepTime,NULL);
 	(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_DEBUG1,"OUT StubSyncTestA PID:0x%x; TASKID:0x%x;",RPC_GetPid(),RPC_TaskSelf());	
 	return (void*)NULL;
 }
@@ -981,7 +981,7 @@ RpcResult_t FunctionStubC(uint32_t count, char *fromProcess, char *toProcess, ui
 }
 
 static RpcResult_t setStubParam(RpcParamData_t *inData, uint32_t pid, uint32_t count, char *fromProcess, char *toProcess,void **outData, uint32_t *outSize) {
-	uint32_t errCode;RpcResult_t ret;
+	RpcResult_t ret;
 
 	inData[0].paramSpec.paramType = RPC_UINT_TYPE;
 	inData[0].paramSpec.paramLeng = 4;
